@@ -25,6 +25,8 @@
  *******************************************************************************/
 
 #include <miopen/batched_transpose_sol.hpp>
+#include <miopen/env.hpp>
+#include <miopen/invoke_params.hpp>
 #include <miopen/tensor.hpp>
 #include <miopen/magic_div.hpp>
 #include <miopen/float_equal.hpp>
@@ -41,6 +43,11 @@
 #define BATCHED_TRANSPOSE_OCCUPANCY 4
 #endif
 
+// Compiler has bug for some of the kernel instances, where pack/ediv is not 1.
+// By default we'll use a smaller list for gfx942 right now but can also force
+// it by using this env var.
+MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_FORCE_HALF_TRANSPOSE_SHORTLIST)
+
 namespace miopen {
 namespace batched_transpose {
 
@@ -79,7 +86,22 @@ static inline const std::vector<BatchedTransposeParam>& GetKernelList(const Exec
     }
     if(data_size == 2)
     {
-        static const std::vector<BatchedTransposeParam> half_kernel_list{
+        static const std::vector<BatchedTransposeParam> half_kernel_list_short{
+            // clang-format off
+            {16, 16, 1, 1, 1, 1},
+            {32, 16, 1, 1, 1, 1},
+            {16, 32, 1, 1, 1, 1},
+            {32, 32, 1, 1, 1, 1},
+
+            {4, 64, 1, 1, 1, 1},
+            {64, 4, 1, 1, 1, 1},
+            {4, 128, 1, 1, 1, 1},
+            {128, 4, 1, 1, 1, 1},
+            {4, 256, 1, 1, 1, 1},
+            {256, 4, 1, 1, 1, 1},
+            // clang-format on
+        };
+        static const std::vector<BatchedTransposeParam> half_kernel_list_long{
             // clang-format off
             {16, 16, 1, 1, 1, 1},
             {32, 16, 1, 1, 1, 1},
@@ -113,28 +135,13 @@ static inline const std::vector<BatchedTransposeParam>& GetKernelList(const Exec
             {64, 64, 4, 4, 4, 4},
             // clang-format on
         };
-        // TODO: gfx940 compiler has bug for some of the kernel, where pack/ediv is not 1
-        // unify this when bug is fixed
-        static const std::vector<BatchedTransposeParam> half_kernel_list_gfx94x{
-            // clang-format off
-            {16, 16, 1, 1, 1, 1},
-            {32, 16, 1, 1, 1, 1},
-            {16, 32, 1, 1, 1, 1},
-            {32, 32, 1, 1, 1, 1},
 
-            {4, 64, 1, 1, 1, 1},
-            {64, 4, 1, 1, 1, 1},
-            {4, 128, 1, 1, 1, 1},
-            {128, 4, 1, 1, 1, 1},
-            {4, 256, 1, 1, 1, 1},
-            {256, 4, 1, 1, 1, 1},
-            // clang-format on
-        };
+        bool force_shortlist   = env::enabled(MIOPEN_FORCE_HALF_TRANSPOSE_SHORTLIST);
         const auto device_name = ctx.GetStream().GetDeviceName();
-        if(StartsWith(device_name, "gfx94"))
-            return half_kernel_list_gfx94x;
-        else
-            return half_kernel_list;
+        if(device_name == "gfx942" || force_shortlist)
+            return half_kernel_list_short;
+
+        return half_kernel_list_long;
     }
     if(data_size == 4)
     {
@@ -413,4 +420,25 @@ size_t BatchedTransposeSolution::GetOutputTensorSize() const
     return miopen::GetTypeSize(data_type) * batch * height * width;
 }
 
+InvokerFactory BatchedTransposeSolution::MakeBatchedTransposeInvokerFactory() const
+{
+    std::vector<OpKernelArg> opArgs = GetKernelArg();
+
+    miopen::InvokerFactory invoker_factory([=](const std::vector<miopen::Kernel>& kernels) mutable {
+        return [=](const miopen::Handle& _handle,
+                   const miopen::AnyInvokeParams& primitive_param) mutable {
+            decltype(auto) invoke_params = primitive_param.CastTo<transpose_invoke_param>();
+
+            const auto k = _handle.Run(kernels[0]);
+
+            opArgs[0] = OpKernelArg(invoke_params.dst);
+            opArgs[1] = OpKernelArg(invoke_params.src);
+
+            k(opArgs);
+        };
+    });
+
+    return invoker_factory;
+}
+
 } // namespace miopen
