@@ -58,6 +58,13 @@ enum BatchNormDirection_t
 
 miopenProblemDirection_t CmdArgToDirection(ConvDirection direction);
 
+void DriverDataType(const std::string& prefix,
+                    std::stringstream& ss,
+                    const miopen::TensorDescriptor& desc);
+void DriverDataType(const std::string& prefix,
+                    std::string& ss,
+                    const miopen::TensorDescriptor& desc);
+
 std::string ConvArgsForMIOpenDriver(const miopen::TensorDescriptor& xDesc,
                                     const miopen::TensorDescriptor& wDesc,
                                     const miopen::ConvolutionDescriptor& convDesc,
@@ -67,13 +74,17 @@ std::string ConvArgsForMIOpenDriver(const miopen::TensorDescriptor& xDesc,
                                     bool print_for_conv_driver = true);
 
 std::string BnormArgsForMIOpenDriver(miopenTensorDescriptor_t xDesc,
-                                     miopenTensorDescriptor_t sMeanDesc,
+                                     miopenTensorDescriptor_t yDesc,
+                                     miopenTensorDescriptor_t scaleDesc,
+                                     miopenTensorDescriptor_t biasDesc,
+                                     miopenTensorDescriptor_t saveMeanDesc,
                                      miopenBatchNormMode_t bn_mode,
                                      const void* resultRunningMean,
                                      const void* resultRunningVariance,
                                      const void* resultSaveMean,
                                      const void* resultSaveInvVariance,
                                      const BatchNormDirection_t& dir,
+                                     miopenActivationDescriptor_t activDesc,
                                      bool print_for_bn_driver = true);
 } // namespace debug
 } // namespace miopen
