@@ -27,6 +27,7 @@
 #pragma once
 
 #include <miopen/solver.hpp>
+#include <miopen/conv/solvers.hpp>
 #include <miopen/fusion.hpp>
 #include <miopen/fusion_plan.hpp>
 #include <utility>
@@ -40,89 +41,10 @@ namespace fusion {
 
 using FusionSolverBase = NonTunableSolverBase<FusionContext, FusionDescription>;
 
-struct FusionTunableSolverBase : SolverMixin<FusionContext, FusionDescription>
-{
-    /// Initializes performance config to the default values.
-    /// The function may involve some heuristic to guess the best solution
-    /// configuration. It is assumed that the function takes constant time
-    /// to finish and does not run kernels to measure performance etc.
-    /// The function shall always return valid config.
-    ///
-    /// The int parameter is needed only to not change the name of the
-    /// function in the derived class. Function declarations that differ
-    /// only by its return type cannot be overloaded.
-    virtual boost::any GetDefaultPerformanceConfig(const FusionContext& ctx,
-                                                   const FusionDescription& problem,
-                                                   int) const = 0;
-
-    /// Should return false if performance config is wrong for a problem.
-    /// Main use is validation of values read from the perf db.
-    virtual bool IsValidPerformanceConfig(const FusionContext& ctx,
-                                          const FusionDescription& problem,
-                                          const PerfConfig& config) const = 0;
-
-    /// Search
-    ///
-    /// The int parameter is needed only to not change the name of the
-    /// function in the derived class. Function declarations that differ
-    /// only by its return type cannot be overloaded.
-    virtual boost::any Search(const FusionContext& ctx,
-                              const FusionDescription& problem,
-                              const AnyInvokeParams& invoke_ctx,
-                              int) const = 0;
-
-    /// Tunable solvers provide a GetSolution that takes a Context and PerformanceConfig
-    virtual ConvSolution GetSolution(const FusionContext& ctx,
-                                     const FusionDescription& problem,
-                                     const PerfConfig& config) const = 0;
-};
-
 template <class PerformanceConfig>
-struct FusionTunableSolver : FusionTunableSolverBase
-{
-    static_assert(std::is_base_of<PerfConfig, PerformanceConfig>{},
-                  "PerformanceConfig must be derived of PerfConfig");
-
-    virtual PerformanceConfig GetDefaultPerformanceConfig(const FusionContext&,
-                                                          const FusionDescription&) const = 0;
-    virtual bool IsValidPerformanceConfig(const FusionContext&,
-                                          const FusionDescription&,
-                                          const PerformanceConfig&) const                 = 0;
-    virtual PerformanceConfig
-    Search(const FusionContext&, const FusionDescription&, const AnyInvokeParams&) const = 0;
-    virtual ConvSolution
-    GetSolution(const FusionContext&, const FusionDescription&, const PerformanceConfig&) const = 0;
-
-    boost::any GetDefaultPerformanceConfig(const FusionContext& ctx,
-                                           const FusionDescription& problem,
-                                           int) const final
-    {
-        return GetDefaultPerformanceConfig(ctx, problem);
-    }
-
-    bool IsValidPerformanceConfig(const FusionContext& ctx,
-                                  const FusionDescription& problem,
-                                  const PerfConfig& config) const final
-    {
-        return IsValidPerformanceConfig(
-            ctx, problem, dynamic_cast<const PerformanceConfig&>(config));
-    }
-
-    boost::any Search(const FusionContext& ctx,
-                      const FusionDescription& problem,
-                      const AnyInvokeParams& invoke_ctx,
-                      int) const final
-    {
-        return Search(ctx, problem, invoke_ctx);
-    }
-
-    ConvSolution GetSolution(const FusionContext& ctx,
-                             const FusionDescription& problem,
-                             const PerfConfig& config) const final
-    {
-        return GetSolution(ctx, problem, dynamic_cast<const PerformanceConfig&>(config));
-    }
-};
+using FusionTunableSolver =
+    TunableSolverMixin<FusionContext, miopen::FusionDescription, PerformanceConfig>;
+;
 
 struct PerformanceConfigConvBiasActivAsm1x1U : conv::PerformanceConfigConvAsm1x1U
 {
@@ -131,34 +53,38 @@ struct PerformanceConfigConvBiasActivAsm1x1U : conv::PerformanceConfigConvAsm1x1
         : PerformanceConfigConvAsm1x1U(-1, -1, -1, -1, -1, -1, -1, -1, false)
     {
     }
-    void HeuristicInit(const FusionContext& ctx, const FusionDescription& problem);
-    bool SetNextValue(const FusionDescription& problem);
+    MIOPEN_INTERNALS_EXPORT void HeuristicInit(const FusionContext& ctx,
+                                               const FusionDescription& problem);
+    MIOPEN_INTERNALS_EXPORT bool SetNextValue(const FusionDescription& problem);
     bool IsValid(const FusionContext&, const FusionDescription& problem) const
     {
         return IsValid(problem);
     }
-    bool IsValid(const FusionDescription& problem) const;
+    MIOPEN_INTERNALS_EXPORT bool IsValid(const FusionDescription& problem) const;
 };
 
 struct ConvBiasActivAsm1x1U : FusionTunableSolver<PerformanceConfigConvBiasActivAsm1x1U>
 {
     const std::string& SolverDbId() const override { return GetSolverDbId<ConvBiasActivAsm1x1U>(); }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
     GetSolution(const FusionContext& context,
                 const FusionDescription& problem,
                 const PerformanceConfigConvBiasActivAsm1x1U& /*config*/) const override;
-    PerformanceConfigConvBiasActivAsm1x1U
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvBiasActivAsm1x1U
     GetDefaultPerformanceConfig(const FusionContext&, const FusionDescription&) const override;
-    PerformanceConfigConvBiasActivAsm1x1U
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvBiasActivAsm1x1U
     Search(const FusionContext& context,
            const FusionDescription& problem,
            const AnyInvokeParams& invoke_params) const override;
-    bool IsValidPerformanceConfig(const FusionContext&,
-                                  const FusionDescription&,
-                                  const PerformanceConfigConvBiasActivAsm1x1U&) const override;
+    MIOPEN_INTERNALS_EXPORT bool
+    IsValidPerformanceConfig(const FusionContext&,
+                             const FusionDescription&,
+                             const PerformanceConfigConvBiasActivAsm1x1U&) const override;
+    MIOPEN_INTERNALS_EXPORT float GetWti(const FusionContext&,
+                                         const FusionDescription&) const override;
 };
 
 using PerformanceConfigConvOclDirectFwdFused = LegacyPerformanceConfig;
@@ -169,20 +95,24 @@ struct ConvOclDirectFwdFused final : FusionTunableSolver<LegacyPerformanceConfig
         return GetSolverDbId<ConvOclDirectFwdFused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& problem,
-                             const PerformanceConfigConvOclDirectFwdFused&) const override;
-    PerformanceConfigConvOclDirectFwdFused
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& context,
+                const FusionDescription& problem,
+                const PerformanceConfigConvOclDirectFwdFused&) const override;
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvOclDirectFwdFused
     GetDefaultPerformanceConfig(const FusionContext&, const FusionDescription&) const override;
-    PerformanceConfigConvOclDirectFwdFused
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvOclDirectFwdFused
     Search(const FusionContext&,
            const FusionDescription&,
            const AnyInvokeParams& invoke_params) const override;
-    bool IsValidPerformanceConfig(const FusionContext&,
-                                  const FusionDescription&,
-                                  const PerformanceConfigConvOclDirectFwdFused&) const override;
+    MIOPEN_INTERNALS_EXPORT bool
+    IsValidPerformanceConfig(const FusionContext&,
+                             const FusionDescription&,
+                             const PerformanceConfigConvOclDirectFwdFused&) const override;
+    MIOPEN_INTERNALS_EXPORT float GetWti(const FusionContext&,
+                                         const FusionDescription& problem) const override;
 };
 
 struct PerformanceConfigConvCKIgemmFwdBiasActivFused
@@ -203,17 +133,19 @@ struct PerformanceConfigConvCKIgemmFwdBiasActivFused
         : PerformanceConfigConvCKIgemmFwdBiasActivFused(0, "")
     {
     }
-    void HeuristicInit(const FusionDescription& fdesc_problem);
-    bool SetNextValue(const FusionDescription& fdesc_problem);
-    bool IsValidValue() const;
-    bool IsValid(const FusionContext&, const FusionDescription& fdesc_problem) const;
+    MIOPEN_INTERNALS_EXPORT void HeuristicInit(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool SetNextValue(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool IsValidValue() const;
+    MIOPEN_INTERNALS_EXPORT bool IsValid(const FusionContext&,
+                                         const FusionDescription& fdesc_problem) const;
 
     template <typename Self, typename F>
     static void Visit(Self&& s, F f)
     {
         f(s.kernel_id, "kernel_id");
     }
-    bool operator==(const PerformanceConfigConvCKIgemmFwdBiasActivFused& other) const;
+    MIOPEN_INTERNALS_EXPORT bool
+    operator==(const PerformanceConfigConvCKIgemmFwdBiasActivFused& other) const;
 
 private:
     template <typename DataType>
@@ -230,20 +162,20 @@ struct ConvCKIgemmFwdBiasActivFused final
         return GetSolverDbId<ConvCKIgemmFwdBiasActivFused>();
     }
 
-    PerformanceConfigConvCKIgemmFwdBiasActivFused
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmFwdBiasActivFused
     GetDefaultPerformanceConfig(const FusionContext& ctx,
                                 const FusionDescription& fdesc_problem) const override;
-    bool IsValidPerformanceConfig(
+    MIOPEN_INTERNALS_EXPORT bool IsValidPerformanceConfig(
         const FusionContext& ctx,
         const FusionDescription& fdesc_problem,
         const PerformanceConfigConvCKIgemmFwdBiasActivFused& config) const override;
-    PerformanceConfigConvCKIgemmFwdBiasActivFused
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmFwdBiasActivFused
     Search(const FusionContext& ctx,
            const FusionDescription& fdesc_problem,
            const AnyInvokeParams& invoke_ctx) const override;
-    bool IsApplicable(const FusionContext& ctx,
-                      const FusionDescription& fdesc_problem) const override;
-    ConvSolution
+    MIOPEN_INTERNALS_EXPORT bool
+    IsApplicable(const FusionContext& ctx, const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
     GetSolution(const FusionContext& ctx,
                 const FusionDescription& fdesc_problem,
                 const PerformanceConfigConvCKIgemmFwdBiasActivFused& config) const override;
@@ -253,6 +185,150 @@ private:
     bool CheckCKApplicability(const miopen::conv::ProblemDescription&) const;
 };
 
+struct PerformanceConfigConvCKIgemmGrpFwdActivFused
+    : PerfConfigBaseCK<PerformanceConfigConvCKIgemmGrpFwdActivFused>
+{
+    int index;
+    std::string kernel_id;
+    std::vector<std::string> valid_kernels;
+    PerformanceConfigConvCKIgemmGrpFwdActivFused(int idx, std::string kernl_id)
+        : index(idx), kernel_id(kernl_id)
+    {
+    }
+    PerformanceConfigConvCKIgemmGrpFwdActivFused()
+        : PerformanceConfigConvCKIgemmGrpFwdActivFused(0, "")
+    {
+    }
+    PerformanceConfigConvCKIgemmGrpFwdActivFused(bool)
+        : PerformanceConfigConvCKIgemmGrpFwdActivFused(0, "")
+    {
+    }
+    MIOPEN_INTERNALS_EXPORT void HeuristicInit(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool SetNextValue(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool IsValidValue() const;
+    MIOPEN_INTERNALS_EXPORT bool IsValid(const FusionContext&,
+                                         const FusionDescription& fdesc_problem) const;
+
+    template <typename Self, typename F>
+    static void Visit(Self&& s, F f)
+    {
+        f(s.kernel_id, "kernel_id");
+    }
+    MIOPEN_INTERNALS_EXPORT bool
+    operator==(const PerformanceConfigConvCKIgemmGrpFwdActivFused& other) const;
+
+private:
+    template <typename DataType>
+    void Init(const miopen::conv::ProblemDescription&);
+    template <typename DataType>
+    bool CheckIsSupportCKArgs(const miopen::conv::ProblemDescription&) const;
+};
+
+struct ConvCKIgemmGrpFwdActivFused final
+    : FusionTunableSolver<PerformanceConfigConvCKIgemmGrpFwdActivFused>
+{
+    const std::string& SolverDbId() const override
+    {
+        return GetSolverDbId<ConvCKIgemmGrpFwdActivFused>();
+    }
+
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmGrpFwdActivFused
+    GetDefaultPerformanceConfig(const FusionContext& ctx,
+                                const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsValidPerformanceConfig(
+        const FusionContext& ctx,
+        const FusionDescription& fdesc_problem,
+        const PerformanceConfigConvCKIgemmGrpFwdActivFused& config) const override;
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmGrpFwdActivFused
+    Search(const FusionContext& ctx,
+           const FusionDescription& fdesc_problem,
+           const AnyInvokeParams& invoke_ctx) const override;
+    MIOPEN_INTERNALS_EXPORT bool
+    IsApplicable(const FusionContext& ctx, const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& ctx,
+                const FusionDescription& fdesc_problem,
+                const PerformanceConfigConvCKIgemmGrpFwdActivFused& config) const override;
+    bool MayNeedWorkspace() const override { return true; }
+    size_t GetWorkspaceSize(const FusionContext&, const FusionDescription&) const override;
+
+private:
+    template <typename DataType>
+    bool CheckCKApplicability(const miopen::conv::ProblemDescription&) const;
+};
+
+struct PerformanceConfigConvCKIgemmGrpFwdBiasActivFused
+    : PerfConfigBaseCK<PerformanceConfigConvCKIgemmGrpFwdBiasActivFused>
+{
+    int index;
+    std::string kernel_id;
+    std::vector<std::string> valid_kernels;
+    PerformanceConfigConvCKIgemmGrpFwdBiasActivFused(int idx, std::string kernl_id)
+        : index(idx), kernel_id(kernl_id)
+    {
+    }
+    PerformanceConfigConvCKIgemmGrpFwdBiasActivFused()
+        : PerformanceConfigConvCKIgemmGrpFwdBiasActivFused(0, "")
+    {
+    }
+    PerformanceConfigConvCKIgemmGrpFwdBiasActivFused(bool)
+        : PerformanceConfigConvCKIgemmGrpFwdBiasActivFused(0, "")
+    {
+    }
+    MIOPEN_INTERNALS_EXPORT void HeuristicInit(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool SetNextValue(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool IsValidValue() const;
+    MIOPEN_INTERNALS_EXPORT bool IsValid(const FusionContext&,
+                                         const FusionDescription& fdesc_problem) const;
+
+    template <typename Self, typename F>
+    static void Visit(Self&& s, F f)
+    {
+        f(s.kernel_id, "kernel_id");
+    }
+    MIOPEN_INTERNALS_EXPORT bool
+    operator==(const PerformanceConfigConvCKIgemmGrpFwdBiasActivFused& other) const;
+
+private:
+    template <typename DataType>
+    void Init(const miopen::conv::ProblemDescription&);
+    template <typename DataType>
+    bool CheckIsSupportCKArgs(const miopen::conv::ProblemDescription&) const;
+};
+
+struct ConvCKIgemmGrpFwdBiasActivFused final
+    : FusionTunableSolver<PerformanceConfigConvCKIgemmGrpFwdBiasActivFused>
+{
+    const std::string& SolverDbId() const override
+    {
+        return GetSolverDbId<ConvCKIgemmGrpFwdBiasActivFused>();
+    }
+
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmGrpFwdBiasActivFused
+    GetDefaultPerformanceConfig(const FusionContext& ctx,
+                                const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsValidPerformanceConfig(
+        const FusionContext& ctx,
+        const FusionDescription& fdesc_problem,
+        const PerformanceConfigConvCKIgemmGrpFwdBiasActivFused& config) const override;
+    MIOPEN_INTERNALS_EXPORT PerformanceConfigConvCKIgemmGrpFwdBiasActivFused
+    Search(const FusionContext& ctx,
+           const FusionDescription& fdesc_problem,
+           const AnyInvokeParams& invoke_ctx) const override;
+    MIOPEN_INTERNALS_EXPORT bool
+    IsApplicable(const FusionContext& ctx, const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& ctx,
+                const FusionDescription& fdesc_problem,
+                const PerformanceConfigConvCKIgemmGrpFwdBiasActivFused& config) const override;
+    bool MayNeedWorkspace() const override { return true; }
+    size_t GetWorkspaceSize(const FusionContext&, const FusionDescription&) const override;
+
+private:
+    template <typename DataType>
+    bool CheckCKApplicability(const miopen::conv::ProblemDescription&) const;
+};
+
 struct PerfConfigConvCKIgemmFwdBiasResAddActivFused
     : PerfConfigBase<PerfConfigConvCKIgemmFwdBiasResAddActivFused>
 {
@@ -271,17 +347,19 @@ struct PerfConfigConvCKIgemmFwdBiasResAddActivFused
         : PerfConfigConvCKIgemmFwdBiasResAddActivFused(0, "")
     {
     }
-    void HeuristicInit(const FusionDescription& fdesc_problem);
-    bool SetNextValue(const FusionDescription& fdesc_problem);
-    bool IsValidValue() const;
-    bool IsValid(const FusionContext&, const FusionDescription& fdesc_problem) const;
+    MIOPEN_INTERNALS_EXPORT void HeuristicInit(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool SetNextValue(const FusionDescription& fdesc_problem);
+    MIOPEN_INTERNALS_EXPORT bool IsValidValue() const;
+    MIOPEN_INTERNALS_EXPORT bool IsValid(const FusionContext&,
+                                         const FusionDescription& fdesc_problem) const;
 
     template <typename Self, typename F>
     static void Visit(Self&& s, F f)
     {
         f(s.kernel_id, "kernel_id");
     }
-    bool operator==(const PerfConfigConvCKIgemmFwdBiasResAddActivFused& other) const;
+    MIOPEN_INTERNALS_EXPORT bool
+    operator==(const PerfConfigConvCKIgemmFwdBiasResAddActivFused& other) const;
 
 private:
     template <typename DataType, typename AccumDataType = DataType>
@@ -298,20 +376,20 @@ struct ConvCKIgemmFwdBiasResAddActivFused final
         return GetSolverDbId<ConvCKIgemmFwdBiasResAddActivFused>();
     }
 
-    PerfConfigConvCKIgemmFwdBiasResAddActivFused
+    MIOPEN_INTERNALS_EXPORT PerfConfigConvCKIgemmFwdBiasResAddActivFused
     GetDefaultPerformanceConfig(const FusionContext& ctx,
                                 const FusionDescription& fdesc_problem) const override;
-    bool IsValidPerformanceConfig(
+    MIOPEN_INTERNALS_EXPORT bool IsValidPerformanceConfig(
         const FusionContext& ctx,
         const FusionDescription& fdesc_problem,
         const PerfConfigConvCKIgemmFwdBiasResAddActivFused& config) const override;
-    PerfConfigConvCKIgemmFwdBiasResAddActivFused
+    MIOPEN_INTERNALS_EXPORT PerfConfigConvCKIgemmFwdBiasResAddActivFused
     Search(const FusionContext& ctx,
            const FusionDescription& fdesc_problem,
            const AnyInvokeParams& invoke_ctx) const override;
-    bool IsApplicable(const FusionContext& ctx,
-                      const FusionDescription& fdesc_problem) const override;
-    ConvSolution
+    MIOPEN_INTERNALS_EXPORT bool
+    IsApplicable(const FusionContext& ctx, const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
     GetSolution(const FusionContext& ctx,
                 const FusionDescription& fdesc_problem,
                 const PerfConfigConvCKIgemmFwdBiasResAddActivFused& config) const override;
@@ -320,6 +398,7 @@ private:
     template <typename DataType, typename AccumDataType = DataType>
     bool CheckCKApplicability(const miopen::conv::ProblemDescription&) const;
 };
+
 struct ConvBinWinogradRxSFused final : FusionSolverBase
 {
     const std::string& SolverDbId() const override
@@ -327,10 +406,13 @@ struct ConvBinWinogradRxSFused final : FusionSolverBase
         return GetSolverDbId<ConvBinWinogradRxSFused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& fdesc_problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool
+    IsApplicable(const FusionContext& context,
+                 const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution GetSolution(
+        const FusionContext& context, const FusionDescription& fdesc_problem) const override;
+    MIOPEN_INTERNALS_EXPORT float GetWti(const FusionContext&,
+                                         const FusionDescription&) const override;
 };
 
 struct ConvBinWinogradRxSf2x3g1Fused final : FusionSolverBase
@@ -340,12 +422,54 @@ struct ConvBinWinogradRxSf2x3g1Fused final : FusionSolverBase
         return GetSolverDbId<ConvBinWinogradRxSf2x3g1Fused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& context, const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT float GetWti(const FusionContext&,
+                                         const FusionDescription&) const override;
 };
 
+template <uint32_t Winodata, uint32_t Winofilter>
+struct ConvWinoFuryRxSFused final : FusionSolverBase
+{
+    const std::string& SolverDbId() const override
+    {
+        return GetSolverDbId<ConvWinoFuryRxSFused<Winodata, Winofilter>>();
+    }
+
+    bool IsApplicable(const FusionContext&, const FusionDescription&) const override;
+    bool IsDynamic() const override { return true; }
+    float GetWti(const FusionContext&, const FusionDescription&) const override;
+    size_t GetWorkspaceSize(const FusionContext&, const FusionDescription&) const override;
+    bool MayNeedWorkspace() const override { return true; }
+
+    ConvSolution GetSolution(const FusionContext&, const FusionDescription&) const override;
+};
+
+#ifndef CONV_WINO_FURY_RXS_CPP
+extern template struct ConvWinoFuryRxSFused<2, 3>;
+// extern template struct ConvWinoFuryRxSFused<3, 2>;
+#endif
+
+template <uint32_t Winodata, uint32_t Winofilter>
+struct ConvWinoRageRxSFused final : FusionSolverBase
+{
+    const std::string& SolverDbId() const override
+    {
+        return GetSolverDbId<ConvWinoRageRxSFused<Winodata, Winofilter>>();
+    }
+
+    bool IsApplicable(const FusionContext&, const FusionDescription&) const override;
+    bool IsDynamic() const override { return true; }
+    float GetWti(const FusionContext&, const FusionDescription&) const override;
+    ConvSolution GetSolution(const FusionContext&, const FusionDescription&) const override;
+};
+
+#ifndef CONV_WINO_FURY_RXS_CPP
+extern template struct ConvWinoRageRxSFused<2, 3>;
+#endif
+
 struct BnFwdInferActivationFused final : FusionSolverBase
 {
     const std::string& SolverDbId() const override
@@ -353,10 +477,10 @@ struct BnFwdInferActivationFused final : FusionSolverBase
         return GetSolverDbId<BnFwdInferActivationFused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& context, const FusionDescription& problem) const override;
 };
 
 struct BnFwdTrgActivationFused final : FusionSolverBase
@@ -366,10 +490,10 @@ struct BnFwdTrgActivationFused final : FusionSolverBase
         return GetSolverDbId<BnFwdTrgActivationFused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& context, const FusionDescription& problem) const override;
 };
 
 struct BnBwdTrgActivationFused final : FusionSolverBase
@@ -379,10 +503,10 @@ struct BnBwdTrgActivationFused final : FusionSolverBase
         return GetSolverDbId<BnBwdTrgActivationFused>();
     }
 
-    bool IsApplicable(const FusionContext& context,
-                      const FusionDescription& problem) const override;
-    ConvSolution GetSolution(const FusionContext& context,
-                             const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT bool IsApplicable(const FusionContext& context,
+                                              const FusionDescription& problem) const override;
+    MIOPEN_INTERNALS_EXPORT ConvSolution
+    GetSolution(const FusionContext& context, const FusionDescription& problem) const override;
 };
 
 } // namespace fusion
