@@ -30,7 +30,6 @@
 #include <miopen/binary_cache.hpp>
 #include <miopen/config.hpp>
 #include <miopen/conv_solution.hpp>
-#include <miopen/env.hpp>
 #include <miopen/execution_context.hpp>
 #include <miopen/handle.hpp>
 #include <miopen/invoke_params.hpp>
@@ -38,6 +37,7 @@
 #include <miopen/timer.hpp>
 #include <miopen/mt_queue.hpp>
 #include <miopen/generic_search_controls.hpp>
+#include <miopen/utility/modified_z.hpp>
 
 #include <algorithm>
 #include <vector>
@@ -47,6 +47,7 @@
 #include <chrono>
 #include <cassert>
 #include <random>
+#include <thread>
 
 namespace miopen {
 namespace solver {
@@ -227,7 +228,7 @@ public:
                 n_recent != 0u ? (static_cast<float>(n_total - n_recent) *
                                   (elapsed_cumulative / static_cast<float>(n_recent)) / 1000.0f)
                                : 0.0f; // paraniod
-            MIOPEN_LOG_W(n_recent << '/' << n_failed << '/' << n_total << ' ' << total_best
+            MIOPEN_LOG_I(n_recent << '/' << n_failed << '/' << n_total << ' ' << total_best
                                   << ", best within recent " << n_within_beat << ": " << best_time
                                   << " #" << n_best << ' ' << best_config << ", ETA:" << eta_sec
                                   << " sec.");
@@ -278,7 +279,7 @@ auto GetAllConfigs(const Solver s, const Context& context, const Problem& proble
 
     ComputedContainer<PerformanceConfig, Context, Problem> all_configs = useSpare ? spare : primary;
     const int n_runs_total = useSpare ? spare_size : primary_size;
-    MIOPEN_LOG_W(s.SolverDbId() << ": Searching the best solution among " << n_runs_total
+    MIOPEN_LOG_I(s.SolverDbId() << ": Searching the best solution among " << n_runs_total
                                 << (useSpare ? " (spare)" : "") << "...");
 
     return all_configs;
@@ -312,6 +313,7 @@ void CompileAgent(size_t thread_index,
                   const Solver& s,
                   const Context& context,
                   const Problem& problem,
+                  const AnyInvokeParams& invoke_ctx,
                   std::vector<PerformanceConfig>& data,
                   ThreadSafeQueue<std::tuple<PerformanceConfig, ConvSolution, bool>>& comp_queue)
 {
@@ -329,12 +331,31 @@ void CompileAgent(size_t thread_index,
         if(current_time - start_time > time_budget)
         {
             MIOPEN_LOG_I2("Thread: " << thread_index << " Done, exhausted time budget");
-            auto tmp = std::make_tuple<PerformanceConfig, ConvSolution, bool>({}, {}, true);
-            comp_queue.push(std::move(tmp));
             break;
         }
         auto& current_config          = data.at(idx);
         ConvSolution current_solution = s.GetSolution(context, problem, current_config);
+
+        // Get provided workspace size or treat as unlimited if not implemented
+        std::size_t provided_size = std::numeric_limits<std::size_t>::max();
+
+        try
+        {
+            provided_size = invoke_ctx.GetWorkspaceSize();
+        }
+        catch(const miopen::Exception&)
+        {
+            MIOPEN_LOG_I2("CompileAgent: Workspace size not implemented, treating as unlimited.");
+        }
+
+        if(provided_size < current_solution.workspace_sz)
+        {
+            MIOPEN_LOG_I2("Thread: " << thread_index
+                                     << " Skipping config due to workspace requirement "
+                                     << current_solution.workspace_sz << " > " << provided_size);
+            continue;
+        }
+
         for(const auto& kernel : current_solution.construction_params)
         {
             if(profile_h.HasProgram(kernel.kernel_file, kernel.comp_options))
@@ -345,6 +366,9 @@ void CompileAgent(size_t thread_index,
             std::move(current_config), std::move(current_solution), false);
         comp_queue.push(std::move(tup));
     }
+    // Signal to mark thread completion
+    auto tmp = std::make_tuple<PerformanceConfig, ConvSolution, bool>({}, {}, true);
+    comp_queue.push(std::move(tmp));
     MIOPEN_LOG_I2("Thread: " << thread_index << " Done, completed tuning");
 }
 
@@ -400,10 +424,11 @@ auto GenericSearch(const Solver s,
         }
     }
 
-    bool is_passed  = false; // left false only if all iterations failed.
-    float best_time = std::numeric_limits<float>::max();
-    size_t n_failed = 0;
-    size_t n_best   = 0;
+    bool is_passed   = false; // left false only if all iterations failed.
+    float best_time  = std::numeric_limits<float>::max();
+    float worst_time = std::numeric_limits<float>::max();
+    size_t n_failed  = 0;
+    size_t n_best    = 0;
     HeartBeat<PerformanceConfig> heartbeat;
     heartbeat.Start();
 
@@ -420,6 +445,7 @@ auto GenericSearch(const Solver s,
                                     std::cref(s),
                                     std::cref(context),
                                     std::cref(problem),
+                                    std::cref(invoke_ctx_),
                                     std::ref(all_configs),
                                     std::ref(solution_queue));
     }
@@ -429,6 +455,7 @@ auto GenericSearch(const Solver s,
         size_t n_current       = 0;
         size_t last_imprv      = 0;
         auto threads_remaining = total_threads;
+        std::vector<float> samples;
         while(true)
         {
             if(n_current >= n_runs_total)
@@ -461,6 +488,7 @@ auto GenericSearch(const Solver s,
                 }
             }
 
+            samples.clear();
             float elapsed_time = 0.0f;
             int ret            = 0;
             MIOPEN_LOG_I2('#' << n_current << '/' << n_failed << '/' << n_runs_total << ' '
@@ -481,8 +509,18 @@ auto GenericSearch(const Solver s,
 
                 invoker = profile_h.PrepareInvoker(*current_solution.invoker_factory,
                                                    current_solution.construction_params);
+
+                // Warm-up run for first time invoker is used
+                if(n_current == 0)
+                {
+                    invoker(profile_h, invoke_ctx);
+                    profile_h.ResetKernelTime();
+                }
+
                 invoker(profile_h, invoke_ctx);
                 elapsed_time = profile_h.GetKernelTime();
+                samples.push_back(elapsed_time);
+                profile_h.ResetKernelTime();
             }
             catch(const std::exception& e)
             {
@@ -503,11 +541,11 @@ auto GenericSearch(const Solver s,
             if(ret == 0)
             {
                 // Smooth the jitter of measurements:
-                // If the 1st probe is NOT too bad (measured time <= 1.10 * best known time),
-                // then re-run it 9 times more and compute average time,
-                // and decide using average of all 10 attempts vs. the best.
+                // If the 1st probe is NOT too bad (measured time <= 1.10 * worst sample of the best
+                // config), then gather 9 more samples, and remove positive z-score outliers. Use
+                // the mean value with outliers removed for calculating best config.
                 constexpr int N_RUNS = 10;
-                if(elapsed_time / best_time < 1.10f)
+                if(elapsed_time / worst_time < 1.10f)
                 {
                     MIOPEN_LOG_I2("Finding average for: " << elapsed_time << " / " << best_time
                                                           << " = " << (elapsed_time / best_time));
@@ -517,7 +555,8 @@ auto GenericSearch(const Solver s,
                         for(int i = 1; i < N_RUNS; ++i)
                         {
                             invoker(profile_h, invoke_ctx);
-                            elapsed_time += profile_h.GetKernelTime();
+                            samples.push_back(profile_h.GetKernelTime());
+                            profile_h.ResetKernelTime();
                         }
                     }
                     catch(...)
@@ -528,7 +567,10 @@ auto GenericSearch(const Solver s,
                     if(ret == 0)
                     {
                         is_passed = true;
-                        elapsed_time /= N_RUNS;
+
+                        // Remove outliers that are more than 2 positive modified z-score's away,
+                        // and get the mean.
+                        elapsed_time = miopen::removeHighOutliersAndGetMean(samples, 2.0f);
                         if(elapsed_time < best_time)
                         {
                             MIOPEN_LOG_I('#' << n_current << '/' << n_failed << '/' << n_runs_total
@@ -536,13 +578,17 @@ auto GenericSearch(const Solver s,
                                              << current_config);
                             best_config = current_config;
                             best_time   = elapsed_time;
-                            n_best      = n_current;
-                            last_imprv  = 0;
+
+                            // Samples gets sorted by the RemoveOutliers call so the last element
+                            // will be the slowest.
+                            worst_time = samples.back();
+                            n_best     = n_current;
+                            last_imprv = 0;
                         }
                         else
                         {
-                            MIOPEN_LOG_I2("Average is not better: " << elapsed_time
-                                                                    << " >= " << best_time);
+                            MIOPEN_LOG_I2("Mean is not better: " << elapsed_time
+                                                                 << " >= " << best_time);
                         }
                     }
                 }
@@ -579,7 +625,7 @@ auto GenericSearch(const Solver s,
     for(auto& agent : compile_agents)
         agent.join();
 
-    MIOPEN_LOG_W("Done: " << n_runs_total << '/' << n_failed << '/' << n_runs_total << ", best #"
+    MIOPEN_LOG_I("Done: " << n_runs_total << '/' << n_failed << '/' << n_runs_total << ", best #"
                           << n_best << ' ' << best_time << ' ' << best_config);
 
     if(!is_passed)
@@ -591,7 +637,7 @@ auto GenericSearch(const Solver s,
     invoker(profile_h, invoke_ctx);
     const auto default_time = profile_h.GetKernelTime();
     const auto score        = (best_time > 0.0f) ? default_time / best_time : 0.0f;
-    MIOPEN_LOG_W("...Score: " << score << " (default time " << default_time << ')');
+    MIOPEN_LOG_I("...Score: " << score << " (default time " << default_time << ')');
 
     return best_config;
 }
