@@ -29,19 +29,21 @@
 #include <miopen/config.h>
 #include <chrono>
 #include <limits>
+#include <thread>
 
-MIOPEN_DECLARE_ENV_VAR(MIOPEN_DEBUG_TUNING_ITERATIONS_MAX,
-                       uint64_t,
-                       std::numeric_limits<std::size_t>::max())
-MIOPEN_DECLARE_ENV_VAR(
+MIOPEN_DECLARE_ENV_VAR_UINT64(MIOPEN_DEBUG_TUNING_ITERATIONS_MAX,
+                              std::numeric_limits<std::size_t>::max())
+MIOPEN_DECLARE_ENV_VAR_UINT64(
     MIOPEN_TUNING_TIME_MS_MAX,
-    uint64_t,
-    (std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::hours{2})).count())
+    std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::hours{2}).count())
+MIOPEN_DECLARE_ENV_VAR_UINT64(
+    MIOPEN_TUNING_PATIENCE,
+    std::numeric_limits<std::size_t>::max()) // End tuning if no improvement in X iterations
+
 #if MIOPEN_USE_COMGR
-MIOPEN_DECLARE_ENV_VAR(MIOPEN_COMPILE_PARALLEL_LEVEL, uint64_t, 1) // COMGR is not parallelizable
+MIOPEN_DECLARE_ENV_VAR_UINT64(MIOPEN_COMPILE_PARALLEL_LEVEL, 1) // COMGR is not parallelizable
 #else
-MIOPEN_DECLARE_ENV_VAR(MIOPEN_COMPILE_PARALLEL_LEVEL,
-                       uint64_t,
-                       std::thread::hardware_concurrency() / 2)
+MIOPEN_DECLARE_ENV_VAR_UINT64(MIOPEN_COMPILE_PARALLEL_LEVEL,
+                              std::thread::hardware_concurrency() / 2)
 #endif
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_COMPILE_ONLY)
