@@ -102,7 +102,7 @@ struct Problem
 
     bool RegisterTensorDescriptor(miopenTensorArgumentId_t name, TensorDescriptor descriptor)
     {
-        return tensor_descriptors.emplace(std::make_pair(name, std::move(descriptor))).second;
+        return tensor_descriptors.try_emplace(name, std::move(descriptor)).second;
     }
 
     void SetDirection(miopenProblemDirection_t value) { direction = value; }
@@ -114,8 +114,9 @@ struct Problem
 
     const OperatorDescriptor& GetOperatorDescriptor() const { return operator_descriptor; }
 
-    std::vector<Solution>
-    FindSolutions(Handle& handle, const FindOptions& options, std::size_t max_solutions) const;
+    std::vector<Solution> FindSolutions(const Handle& handle,
+                                        const FindOptions& options,
+                                        std::size_t max_solutions) const;
 
     conv::ProblemDescription AsConvolution() const;
     activ::ProblemDescription AsActivation() const;
@@ -182,20 +183,20 @@ private:
     std::unordered_map<miopenTensorArgumentId_t, TensorDescriptor> tensor_descriptors;
     OperatorDescriptor operator_descriptor;
 
-    std::vector<Solution> FindSolutionsImpl(Handle& handle,
+    std::vector<Solution> FindSolutionsImpl(const Handle& handle,
                                             const FindOptions& options,
                                             std::size_t max_solutions,
                                             const Buffers& buffers,
                                             const ConvolutionDescriptor& conv_desc,
                                             const Problem& original) const;
 
-    std::vector<Solution> FindSolutionsImpl(Handle& handle,
+    std::vector<Solution> FindSolutionsImpl(const Handle& handle,
                                             const FindOptions& options,
                                             std::size_t max_solutions,
                                             const Buffers& buffers,
                                             const MhaDescriptor& mha_desc) const;
 
-    std::vector<Solution> FindSolutionsImpl(Handle& handle,
+    std::vector<Solution> FindSolutionsImpl(const Handle& handle,
                                             const FindOptions& options,
                                             std::size_t max_solutions,
                                             const Buffers& buffers,
@@ -218,8 +219,9 @@ struct MIOPEN_INTERNALS_EXPORT FusedProblem
         // Not implemented, but silently
     }
 
-    [[nodiscard]] std::vector<Solution>
-    FindSolutions(Handle& handle, const FindOptions& options, std::size_t max_solutions) const;
+    [[nodiscard]] std::vector<Solution> FindSolutions(const Handle& handle,
+                                                      const FindOptions& options,
+                                                      std::size_t max_solutions) const;
 
     void PropagateDescriptors();
 
