@@ -57,7 +57,7 @@ void LogCmdConvolution(const miopen::TensorDescriptor& x,
 
 namespace miopen {
 
-void Solution::Run(Handle& handle,
+void Solution::Run(const Handle& handle,
                    const std::unordered_map<miopenTensorArgumentId_t, RunInput>& inputs,
                    Data_t workspace,
                    std::size_t workspace_size)
@@ -148,7 +148,7 @@ void Solution::LogDriverCommand(const FusedProblem& problem_) const
     /// \todo: add logging of some command to reproduce current solution or at least problem
 }
 
-void Solution::RunImpl(Handle& handle,
+void Solution::RunImpl(const Handle& handle,
                        const std::unordered_map<miopenTensorArgumentId_t, RunInput>& inputs,
                        Data_t workspace,
                        std::size_t workspace_size,
@@ -246,7 +246,7 @@ void Solution::RunImpl(Handle& handle,
     auto conv_ctx = ExecutionContext{&handle};
     conv_problem.SetupFloats(conv_ctx);
 
-    decltype(auto) db        = GetDb(conv_ctx);
+    decltype(auto) db        = MakeConvDbGetter(conv_ctx);
     const auto conv_solution = GetSolver().GetSolver().FindSolution(
         conv_ctx, conv_problem, db, invoke_ctx, perf_cfg.value_or(""));
 
@@ -257,7 +257,7 @@ void Solution::RunImpl(Handle& handle,
     checkNumericsOutput_();
 }
 
-void Solution::RunImpl(Handle& handle,
+void Solution::RunImpl(const Handle& handle,
                        const std::unordered_map<miopenTensorArgumentId_t, RunInput>& inputs,
                        Data_t workspace,
                        std::size_t workspace_size,
@@ -400,32 +400,15 @@ void Solution::RunImpl(Handle& handle,
         return;
     }
 
-    auto getSolution = [&](const ExecutionContext& ctx) {
-        auto solverId = GetSolver();
-        solver::mha::MhaForward mhaForward;
-        solver::mha::MhaBackward mhaBackward;
-        solver::mha::MhaCKFlashAttentionV2Forward ckMhaForward;
-
-        if(solverId == ckMhaForward.SolverDbId())
-        {
-            return ckMhaForward.GetSolution(ctx, problem_description);
-        }
-        else if(solverId == mhaForward.SolverDbId())
-        {
-            return mhaForward.GetSolution(ctx, problem_description);
-        }
-        else if(solverId == mhaBackward.SolverDbId())
-        {
-            return mhaBackward.GetSolution(ctx, problem_description);
-        }
-
-        MIOPEN_THROW("No MHA solver with matching SolverDbId of " + solverId.ToString());
-    };
+    solver::mha::MhaForward mhaForward;
+    solver::mha::MhaBackward mhaBackward;
 
     if(!kernels.empty())
     {
         const auto ctx          = ExecutionContext{&handle};
-        const auto mha_solution = getSolution(ctx);
+        const auto mha_solution = GetSolver() == mhaForward.SolverDbId()
+                                      ? mhaForward.GetSolution(ctx, problem_description)
+                                      : mhaBackward.GetSolution(ctx, problem_description);
         auto kernel_handles     = std::vector<Kernel>{std::begin(kernels), std::end(kernels)};
 
         invoker = (*mha_solution.invoker_factory)(kernel_handles);
@@ -442,8 +425,11 @@ void Solution::RunImpl(Handle& handle,
         return;
     }
 
-    auto ctx                = ExecutionContext{&handle};
-    const auto mha_solution = getSolution(ctx);
+    auto ctx = ExecutionContext{&handle};
+
+    const auto mha_solution = GetSolver() == mhaForward.SolverDbId()
+                                  ? mhaForward.GetSolution(ctx, problem_description)
+                                  : mhaBackward.GetSolution(ctx, problem_description);
 
     invoker =
         handle.PrepareInvoker(*mha_solution.invoker_factory, mha_solution.construction_params);
@@ -451,7 +437,7 @@ void Solution::RunImpl(Handle& handle,
     (*invoker)(handle, invoke_ctx);
 }
 
-void Solution::RunImpl(Handle& handle,
+void Solution::RunImpl(const Handle& handle,
                        const std::unordered_map<miopenTensorArgumentId_t, RunInput>& inputs,
                        Data_t /*workspace*/,
                        std::size_t /*workspace_size*/,
@@ -554,7 +540,7 @@ void Solution::RunImpl(Handle& handle,
     (*invoker)(handle, invoke_ctx);
 }
 
-void Solution::RunImpl(Handle& handle,
+void Solution::RunImpl(const Handle& handle,
                        const std::unordered_map<miopenTensorArgumentId_t, RunInput>& inputs,
                        Data_t /*workspace*/,
                        std::size_t /*workspace_size*/,
