@@ -59,14 +59,6 @@
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_ENABLE_DEPRECATED_SOLVERS)
 
 namespace miopen {
-
-namespace debug {
-
-// NOLINTNEXTLINE (cppcoreguidelines-avoid-non-const-global-variables)
-bool enable_deprecated_solvers = false;
-
-} // namespace debug
-
 namespace solver {
 
 std::ostream& operator<<(std::ostream& os, const KernelInfo& k)
@@ -141,6 +133,7 @@ struct IdRegistryEntry
     Primitive primitive            = Primitive::Convolution;
     miopenConvAlgorithm_t convAlgo = miopenConvolutionAlgoDirect;
     AnySolver solver;
+    const SolverBase* solver_base = nullptr;
 };
 
 struct IdRegistryData
@@ -198,6 +191,16 @@ AnySolver Id::GetSolver() const
     return it != IdRegistry().value_to_entry.end() ? it->second.solver : AnySolver{};
 }
 
+const SolverBase* Id::GetSolverBase() const
+{
+    if(!IsValid())
+        return nullptr;
+    const auto it = IdRegistry().value_to_entry.find(value);
+    if(it == IdRegistry().value_to_entry.end())
+        return nullptr;
+    return it->second.solver_base;
+}
+
 std::string Id::GetAlgo(miopen::conv::Direction dir) const
 {
     return ConvolutionAlgoToDirectionalString(GetAlgo(), dir);
@@ -283,9 +286,21 @@ template <class TSolver>
 inline void
 RegisterWithSolver(IdRegistryData& registry, uint64_t value, TSolver, miopenConvAlgorithm_t algo)
 {
-    if(!Register(registry, value, TSolver{}.SolverDbId(), algo))
+    static const TSolver solver_base;
+    if(!Register(registry, value, solver_base.SolverDbId(), algo))
         return;
-    registry.value_to_entry.at(value).solver = TSolver{};
+    auto& entry       = registry.value_to_entry.at(value);
+    entry.solver      = TSolver{};
+    entry.solver_base = &solver_base;
+}
+
+template <class Solver>
+void RegisterWithSolver(IdRegistryData& registry, uint64_t value, Primitive primitive)
+{
+    static const Solver solver_base;
+    if(!Register(registry, value, primitive, solver_base.SolverDbId()))
+        return;
+    registry.value_to_entry.at(value).solver_base = &solver_base;
 }
 
 inline SolverRegistrar::SolverRegistrar(IdRegistryData& registry)
@@ -547,30 +562,21 @@ inline SolverRegistrar::SolverRegistrar(IdRegistryData& registry)
     Register(registry, ++id, Primitive::Activation, activ::ActivBwdSolver0{}.SolverDbId());
     Register(registry, ++id, Primitive::Activation, activ::ActivBwdSolver1{}.SolverDbId());
 
-    Register(
-        registry, ++id, Primitive::Batchnorm, batchnorm::BnFwdTrainingSpatialSingle{}.SolverDbId());
+    // combine BnFwdTrainingSpatialMultiple and BnFwdTrainingSpatialSingle
+    RegisterWithSolver<batchnorm::BnFwdTrainingSpatial>(registry, ++id, Primitive::Batchnorm);
 
     RegisterWithSolver(
         registry, ++id, conv::ConvCkIgemmFwdV6r1DlopsNchw{}, miopenConvolutionAlgoImplicitGEMM);
 
-    Register(registry,
-             ++id,
-             Primitive::Batchnorm,
-             batchnorm::BnFwdTrainingSpatialMultiple{}.SolverDbId());
+    ++id; // removed solver BnFwdTrainingSpatialMultiple (it is now part of BnFwdTrainingSpatial)
+    RegisterWithSolver<batchnorm::BnFwdTrainingPerActivation>(registry, ++id, Primitive::Batchnorm);
 
-    Register(
-        registry, ++id, Primitive::Batchnorm, batchnorm::BnFwdTrainingPerActivation{}.SolverDbId());
+    // combine BnBwdTrainingSpatialMultiple and BnBwdTrainingSpatialSingle
+    RegisterWithSolver<batchnorm::BnBwdTrainingSpatial>(registry, ++id, Primitive::Batchnorm);
+    ++id; // removed solver BnBwdTrainingSpatialMultiple (it is now part of BnBwdTrainingSpatial)
+    RegisterWithSolver<batchnorm::BnBwdTrainingPerActivation>(registry, ++id, Primitive::Batchnorm);
 
-    Register(
-        registry, ++id, Primitive::Batchnorm, batchnorm::BnBwdTrainingSpatialSingle{}.SolverDbId());
-    Register(registry,
-             ++id,
-             Primitive::Batchnorm,
-             batchnorm::BnBwdTrainingSpatialMultiple{}.SolverDbId());
-    Register(
-        registry, ++id, Primitive::Batchnorm, batchnorm::BnBwdTrainingPerActivation{}.SolverDbId());
-
-    Register(registry, ++id, Primitive::Batchnorm, batchnorm::BnFwdInference{}.SolverDbId());
+    RegisterWithSolver<batchnorm::BnFwdInference>(registry, ++id, Primitive::Batchnorm);
 
     Register(registry, ++id, Primitive::Pooling, pooling::PoolingForward2d{}.SolverDbId());
     Register(registry, ++id, Primitive::Pooling, pooling::PoolingForwardNd{}.SolverDbId());
@@ -626,27 +632,18 @@ inline SolverRegistrar::SolverRegistrar(IdRegistryData& registry)
                        ++id,
                        conv::ConvHipImplicitGemm3DGroupBwdXdlops{},
                        miopenConvolutionAlgoImplicitGEMM);
-    Register(registry, ++id, Primitive::Batchnorm, batchnorm::BnCKFwdInference{}.SolverDbId());
-    Register(registry, ++id, Primitive::Batchnorm, batchnorm::BnCKBwdBackward{}.SolverDbId());
-    Register(registry, ++id, Primitive::Batchnorm, batchnorm::BnCKFwdTraining{}.SolverDbId());
+    ++id; // removed batchnorm::BnCKFwdInference
+    ++id; // removed batchnorm::BnCKBwdBackward
+    ++id; // removed batchnorm::BnCKFwdTraining
     Register(
         registry, ++id, Primitive::Normalization, layernorm::Layernorm2DCKForward{}.SolverDbId());
     Register(
         registry, ++id, Primitive::Normalization, layernorm::Layernorm4DCKForward{}.SolverDbId());
     Register(registry, ++id, Primitive::Normalization, layernorm::LayernormForward{}.SolverDbId());
     Register(registry, ++id, Primitive::Reduce, reduce::SumForward{}.SolverDbId());
-    RegisterWithSolver(registry,
-                       ++id,
-                       conv::ConvHipImplicitGemmF16F8F16FwdXdlops{},
-                       miopenConvolutionAlgoImplicitGEMM);
-    RegisterWithSolver(registry,
-                       ++id,
-                       conv::ConvHipImplicitGemmF16F8F16BwdXdlops{},
-                       miopenConvolutionAlgoImplicitGEMM);
-    RegisterWithSolver(registry,
-                       ++id,
-                       conv::ConvHipImplicitGemmF16F8F16WrwXdlops{},
-                       miopenConvolutionAlgoImplicitGEMM);
+    ++id;
+    ++id;
+    ++id;
     Register(registry,
              ++id,
              Primitive::Fusion,
@@ -707,17 +704,33 @@ inline SolverRegistrar::SolverRegistrar(IdRegistryData& registry)
              ++id,
              Primitive::MultiMarginLoss,
              multimarginloss::MultiMarginLossForward{}.SolverDbId());
+    // removed CK MHA solver
+    ++id;
 
-    Register(registry, ++id, Primitive::Mha, mha::MhaCKFlashAttentionV2Forward{}.SolverDbId());
+    RegisterWithSolver(
+        registry, ++id, conv::ConvWinoRageRxS<2, 3>{}, miopenConvolutionAlgoWinograd);
+    Register(registry,
+             ++id,
+             Primitive::Fusion,
+             fusion::ConvWinoRageRxSFused<2, 3>{}.SolverDbId(),
+             miopenConvolutionAlgoWinograd);
+    Register(registry,
+             ++id,
+             Primitive::Fusion,
+             fusion::ConvCKIgemmGrpFwdBiasActivFused{}.SolverDbId(),
+             miopenConvolutionAlgoImplicitGEMM);
+    Register(registry,
+             ++id,
+             Primitive::Fusion,
+             fusion::ConvCKIgemmGrpFwdActivFused{}.SolverDbId(),
+             miopenConvolutionAlgoImplicitGEMM);
     // IMPORTANT: New solvers should be added to the end of the function, and don't leave a white
     // space between this comment and the newly registered solver(s)!
 }
 
 bool ThisSolverIsDeprecatedStatic::IsDisabled(const ExecutionContext& ctx)
 {
-    static const bool device_is_allowed = [&]() {
-        if(miopen::debug::enable_deprecated_solvers)
-            return true;
+    const bool device_is_allowed = [&]() {
         if(env::enabled(MIOPEN_DEBUG_ENABLE_DEPRECATED_SOLVERS))
             return true;
         const auto device = ctx.GetStream().GetTargetProperties().Name();
