@@ -26,6 +26,7 @@
 
 #include <cstddef>
 #include <miopen/conv/solvers.hpp>
+#include <miopen/env.hpp>
 #include <miopen/handle.hpp>
 #include <miopen/generic_search.hpp>
 #include <miopen/conv/wrw_invoke_params.hpp>
@@ -788,6 +789,18 @@ bool PerformanceConfigAsmImplicitGemmGTCWrwXdlopsNHWC::IsValid(
         problem.IsFp16() ? miopenHalf : (problem.IsBfp16() ? miopenBFloat16 : miopenFloat);
     const auto group = problem.GetGroupCount();
 
+    {
+        size_t current_block_size, current_grid_size, current_splits_4G;
+        std::tie(current_block_size, current_grid_size, current_splits_4G) =
+            GetImplicitGemmGtcDynamicWrwXdlopsNHWCKernel(problem, *this);
+
+        if(current_block_size * current_grid_size * current_splits_4G > 0xffffffffULL)
+            return false;
+
+        if(current_splits_4G == 0)
+            return false;
+    }
+
     bool unit_conv = (x == 1) && (y == 1) && (stride_h == 1) && (stride_w == 1) &&
                      (dilation_h == 1) && (dilation_w == 1) && (pad_h == 0) && (pad_w == 0);
 
@@ -816,13 +829,6 @@ bool PerformanceConfigAsmImplicitGemmGTCWrwXdlopsNHWC::IsValid(
             return false;
     }
 
-    size_t current_block_size, current_grid_size, current_splits_4G;
-    std::tie(current_block_size, current_grid_size, current_splits_4G) =
-        GetImplicitGemmGtcDynamicWrwXdlopsNHWCKernel(problem, *this);
-
-    if(current_block_size * current_grid_size * current_splits_4G > 0xffffffffULL)
-        return false;
-
     return true;
 }
 
@@ -889,8 +895,8 @@ bool ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC::IsApplicable(
 #endif
 
     const auto device_name = ctx.GetStream().GetDeviceName();
-    if((device_name != "gfx908") && (device_name != "gfx90a") &&
-       (!StartsWith(device_name, "gfx94")))
+    if((device_name != "gfx908") && (device_name != "gfx90a") && (device_name != "gfx942") &&
+       (!StartsWith(device_name, "gfx95")))
         return false;
 
     if(!ctx.use_asm_kernels)
@@ -909,7 +915,8 @@ bool ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC::IsApplicable(
         return false;
 
     if(!problem.IsFp32() && !problem.IsFp16() &&
-       !(problem.IsBfp16() && (device_name == "gfx90a" || StartsWith(device_name, "gfx94"))))
+       !(problem.IsBfp16() &&
+         (device_name == "gfx90a" || device_name == "gfx942" || StartsWith(device_name, "gfx95"))))
         return false;
 
     if(problem.IsTensorsCasted())
@@ -918,7 +925,7 @@ bool ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC::IsApplicable(
     if(!ctx.rmv.IsV3())
         return false;
 
-    const auto target = ctx.GetStream().GetTargetProperties();
+    const auto& target = ctx.GetStream().GetTargetProperties();
     if(target.Xnack() && *target.Xnack())
         return false; // NOLINT (readability-simplify-boolean-expr)
 
@@ -1117,8 +1124,8 @@ ConvSolution ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC::GetSolution(
 
     const auto isFp16                 = problem.IsFp16();
     const auto isGfx90aFp16altSupport = (ctx.GetStream().GetDeviceName() == "gfx90a") && isFp16;
-    const bool need_cast              = (problem.IsBfp16() && gemm_k_global_splits >= 1) ||
-                           (isFp16 && gemm_k_global_splits >= 1 &&
+    const bool need_cast              = (problem.IsBfp16() && config.gemm_k_global_split >= 1) ||
+                           (isFp16 && config.gemm_k_global_split >= 1 &&
                             (config.tensor_b_thread_lengths[3] == 1 || config.vector_store == 1));
 
     const auto is_nchw = problem.IsLayoutDefault();
@@ -1127,26 +1134,12 @@ ConvSolution ConvAsmImplicitGemmGTCDynamicWrwXdlopsNHWC::GetSolution(
     std::ostringstream options;                   // Common options for both kernels.
     std::ostringstream msg;
     GenerateClangDefsym(options, "ROCM_METADATA_VERSION", ctx.rmv.UseV3() ? 5 : 4);
-    if(ctx.GetStream().GetDeviceName() == "gfx940")
-    {
-        GenerateClangDefsym(options, "force_sc0_sc1", 1);
-        GenerateClangDefsym(options, "atomic_add_using_cas", 0);
-        if(miopen::IsLogging(LoggingLevel::Info2))
-            msg << ", force_sc0_sc1:1, atomic_add_using_cas:0 (gfx940)";
-    }
-    else if(ctx.GetStream().GetDeviceName() == "gfx941")
-    {
-        GenerateClangDefsym(options, "force_sc0_sc1", 1);
-        GenerateClangDefsym(options, "atomic_add_using_cas", 1);
-        if(miopen::IsLogging(LoggingLevel::Info2))
-            msg << ", force_sc0_sc1:1, atomic_add_using_cas:1 (gfx941)";
-    }
-    else if(StartsWith(ctx.GetStream().GetDeviceName(), "gfx94"))
+    if(ctx.GetStream().GetDeviceName() == "gfx942")
     {
         GenerateClangDefsym(options, "force_sc0_sc1", 0);
         GenerateClangDefsym(options, "atomic_add_using_cas", 0);
         if(miopen::IsLogging(LoggingLevel::Info2))
-            msg << ", force_sc0_sc1:0, atomic_add_using_cas:0 (gfx942+)";
+            msg << ", force_sc0_sc1:0, atomic_add_using_cas:0 (gfx942)";
     }
 
     std::ostringstream opts_0(options.str(), std::ios_base::ate); // Options for normal kernel.
