@@ -28,6 +28,7 @@
 #include <cstdint>
 
 #include <miopen/conv/solvers.hpp>
+#include <miopen/env.hpp>
 #include <miopen/generic_search.hpp>
 #include <miopen/conv/data_invoke_params.hpp>
 #include <miopen/solver/problem_description_interpreter.hpp>
@@ -39,6 +40,7 @@
 #endif
 #include <miopen/solver/implicitgemm_ck_util.hpp>
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_3D_CONV_IMPLICIT_GEMM_HIP_FWD_XDLOPS)
+MIOPEN_DECLARE_ENV_VAR_UINT64(MIOPEN_DEBUG_3D_CONV_IMPLICIT_GEMM_HIP_FWD_XDLOPS_IDX_OVERRIDE);
 
 namespace miopen {
 namespace solver {
@@ -359,7 +361,69 @@ void PerformanceConfigHipImplicitGemm3DGroupFwdXdlops::Init(const ProblemDescrip
             FillValidKernelsIDs<DeviceOpGFwdDefaultPtrs<DataType>, CKArgs<DataType>>(problem);
         break;
     }
-    index     = 0;
+    index = 0;
+
+    auto find_kernel = [&valid_kernels = std::as_const(valid_kernels)](
+                           const std::size_t& index, const std::string& kernel_id) -> std::size_t {
+        // Check if valid_kernels[index] equals kernel_id.
+        if(index < valid_kernels.size() && valid_kernels[index] == kernel_id)
+            return index;
+
+        // Linear search for kernel_id in valid_kernels.
+        auto it = std::find(valid_kernels.begin(), valid_kernels.end(), kernel_id);
+        if(it != valid_kernels.end())
+            return static_cast<std::size_t>(it - valid_kernels.begin());
+
+        // Not found: return 0
+        MIOPEN_LOG_E("Not found :" << index << "-" << kernel_id);
+        return 0;
+    };
+
+    // for BF16 and FP16
+    index = env::value(MIOPEN_DEBUG_3D_CONV_IMPLICIT_GEMM_HIP_FWD_XDLOPS_IDX_OVERRIDE);
+    if(index == 0 && problem.GetInChannels() > 8 && problem.GetGroupCount() == 1 &&
+       problem.GetAlphaBetaCase() == DEFAULT)
+    {
+        int K = problem.GetOutChannels();
+        if(problem.GetInDataType() == miopenBFloat16)
+        {
+            if(K < 64)
+            {
+                index =
+                    find_kernel(38,
+                                "DeviceGroupedConvFwdMultipleABD_Xdl_CShuffle_V3"
+                                "<256, 64, 64, 64, Default, 32, 32, 1, 1, 8, 8, 8, 1, 1, "
+                                "BlkGemmPipelineScheduler: Intrawave, BlkGemmPipelineVersion: v3>");
+            }
+            else
+            {
+                index =
+                    find_kernel(30,
+                                "DeviceGroupedConvFwdMultipleABD_Xdl_CShuffle_V3"
+                                "<256, 128, 128, 64, Default, 32, 32, 2, 2, 8, 8, 8, 1, 1, "
+                                "BlkGemmPipelineScheduler: Intrawave, BlkGemmPipelineVersion: v3>");
+            }
+        }
+        else if(problem.GetInDataType() == miopenHalf)
+        {
+            if(K < 64)
+            {
+                index =
+                    find_kernel(57,
+                                "DeviceGroupedConvFwdMultipleABD_Xdl_CShuffle_V3"
+                                "<64, 16, 16, 128, Default, 16, 16, 1, 1, 8, 8, 4, 1, 1, "
+                                "BlkGemmPipelineScheduler: Interwave, BlkGemmPipelineVersion: v1>");
+            }
+            else
+            {
+                index =
+                    find_kernel(31,
+                                "DeviceGroupedConvFwdMultipleABD_Xdl_CShuffle_V3"
+                                "<256, 128, 128, 64, Default, 32, 32, 2, 2, 8, 8, 8, 1, 1, "
+                                "BlkGemmPipelineScheduler: Intrawave, BlkGemmPipelineVersion: v3>");
+            }
+        }
+    }
     kernel_id = valid_kernels[index];
 }
 
@@ -410,8 +474,8 @@ void PerformanceConfigHipImplicitGemm3DGroupFwdXdlops::HeuristicInit(
     case miopenBFloat16: Init<ck::bhalf_t>(problem); break;
     case miopenInt64:
     case miopenInt32:
-    case miopenFloat8:
-    case miopenBFloat8:
+    case miopenFloat8_fnuz:
+    case miopenBFloat8_fnuz:
     case miopenDouble: break;
     }
 #endif
@@ -424,6 +488,11 @@ bool PerformanceConfigHipImplicitGemm3DGroupFwdXdlops::SetNextValue(
     {
         HeuristicInit(problem);
         assert(!valid_kernels.empty());
+        if(index != 0)
+        {
+            index     = 0;
+            kernel_id = valid_kernels[index];
+        }
         return true;
     }
     if((index + 1) < valid_kernels.size())
@@ -453,8 +522,8 @@ bool PerformanceConfigHipImplicitGemm3DGroupFwdXdlops::IsValid(
     case miopenBFloat16: return CheckIsSupportCKArgs<ck::bhalf_t>(problem);
     case miopenInt64:
     case miopenInt32:
-    case miopenFloat8:
-    case miopenBFloat8:
+    case miopenFloat8_fnuz:
+    case miopenBFloat8_fnuz:
     case miopenDouble: break;
     }
 #endif
@@ -506,7 +575,6 @@ bool ConvHipImplicitGemm3DGroupFwdXdlops::IsApplicable(
 #if MIOPEN_BACKEND_HIP && MIOPEN_USE_COMPOSABLEKERNEL
     if(env::disabled(MIOPEN_DEBUG_3D_CONV_IMPLICIT_GEMM_HIP_FWD_XDLOPS))
         return false;
-    // check if type float else return false
     if(problem.GetConv().attribute.deterministic)
         return false;
     if(!problem.AllTensorsDimsFitIntoInt())
@@ -532,14 +600,42 @@ bool ConvHipImplicitGemm3DGroupFwdXdlops::IsApplicable(
     case miopenBFloat16: return CheckCKApplicability<ck::bhalf_t>(problem);
     case miopenInt64:
     case miopenInt32:
-    case miopenFloat8:
-    case miopenBFloat8:
+    case miopenFloat8_fnuz:
+    case miopenBFloat8_fnuz:
     case miopenDouble: break;
     }
 #endif
     return false;
 }
 
+float ConvHipImplicitGemm3DGroupFwdXdlops::GetWti(
+    const ExecutionContext&, const miopen::conv::ProblemDescription& problem) const
+{
+    decltype(auto) xDesc = problem.GetIn();
+    decltype(auto) wDesc = problem.GetWeights();
+
+    if(xDesc.GetType() == miopenHalf || xDesc.GetType() == miopenBFloat16)
+    {
+        std::size_t in_n, in_c, w_x, w_y, w_d;
+        std::tie(in_n, in_c)    = tie_pick<0, 1>()(xDesc.GetLengths());
+        std::tie(w_x, w_y, w_d) = tie_pick<2, 3, 4>()(wDesc.GetLengths());
+        // For cases where the filter shape is not 1x1x1 and the input channel (in_c) is greater
+        // than 8, CK's implementation offers better performance.
+        if((w_x == 1 && w_y == 1 && w_d == 1) == false)
+        {
+            if(in_c < 8 && in_n < 4)
+            {
+                return 0.00002; // force disable
+            }
+            else
+            {
+                return 1.0; // force enable
+            }
+        }
+    }
+    return 0.02f;
+}
+
 ConvSolution ConvHipImplicitGemm3DGroupFwdXdlops::GetSolution(
     [[maybe_unused]] const ExecutionContext& ctx,
     [[maybe_unused]] const ProblemDescription& problem,
@@ -554,18 +650,21 @@ ConvSolution ConvHipImplicitGemm3DGroupFwdXdlops::GetSolution(
             {
             case BILINEAR:
                 return InitInvokerFactoryFwdNCHW<3,
+                                                 false,
                                                  DeviceOpGFwdBilinearPtrs<T>,
                                                  CKArgs<T>,
                                                  miopen::conv::DataInvokeParams>(
                     ctx, problem, config.kernel_id);
             case SCALE:
                 return InitInvokerFactoryFwdNCHW<3,
+                                                 false,
                                                  DeviceOpGFwdScalePtrs<T>,
                                                  CKArgs<T>,
                                                  miopen::conv::DataInvokeParams>(
                     ctx, problem, config.kernel_id);
             default:
                 return InitInvokerFactoryFwdNCHW<3,
+                                                 false,
                                                  DeviceOpGFwdDefaultPtrs<T>,
                                                  CKArgs<T>,
                                                  miopen::conv::DataInvokeParams>(
@@ -577,17 +676,20 @@ ConvSolution ConvHipImplicitGemm3DGroupFwdXdlops::GetSolution(
             switch(problem.GetAlphaBetaCase())
             {
             case BILINEAR:
-                return InitInvokerFactoryNHWC<DeviceOpGFwdBilinearPtrs<T>,
+                return InitInvokerFactoryNHWC<false,
+                                              DeviceOpGFwdBilinearPtrs<T>,
                                               CKArgs<T>,
                                               miopen::conv::DataInvokeParams>(
                     ctx, problem, config.kernel_id);
             case SCALE:
-                return InitInvokerFactoryNHWC<DeviceOpGFwdScalePtrs<T>,
+                return InitInvokerFactoryNHWC<false,
+                                              DeviceOpGFwdScalePtrs<T>,
                                               CKArgs<T>,
                                               miopen::conv::DataInvokeParams>(
                     ctx, problem, config.kernel_id);
             default:
-                return InitInvokerFactoryNHWC<DeviceOpGFwdDefaultPtrs<T>,
+                return InitInvokerFactoryNHWC<false,
+                                              DeviceOpGFwdDefaultPtrs<T>,
                                               CKArgs<T>,
                                               miopen::conv::DataInvokeParams>(
                     ctx, problem, config.kernel_id);
