@@ -23,13 +23,14 @@
  * SOFTWARE.
  *
  *******************************************************************************/
+
 #include <miopen/conv/invokers/impl_gemm.hpp>
 #include <miopen/conv/solvers.hpp>
-#include <miopen/handle.hpp>
+#include <miopen/env.hpp>
 #include <miopen/generic_search.hpp>
-#include <miopen/solver/implicitgemm_util.hpp>
+#include <miopen/solver/implicitgemm_static_ck_util.hpp>
+#include <miopen/solver/static_ck_common.hpp>
 
-#include <cstddef>
 #include <numeric>
 
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_BWD_V4R1)
@@ -184,8 +185,8 @@ PerformanceImplicitGemmBwdDataV4R1::CalculateGemmABlockCopyPerformanceParameters
 {
     int ClusterLengths_GemmK  = 0;
     int ClusterLengths_GemmM  = 0;
-    int SrcDataPerRead_GemmM  = amd_buffer_load_max_length<float>();
-    int DstDataPerWrite_GemmM = amd_lds_write_max_length<float>();
+    int SrcDataPerRead_GemmM  = static_ck::amd_buffer_load_max_length<float>();
+    int DstDataPerWrite_GemmM = static_ck::amd_lds_write_max_length<float>();
 
     try
     {
@@ -252,8 +253,8 @@ PerformanceImplicitGemmBwdDataV4R1::CalculateGemmBBlockCopyPerformanceParameters
 {
     int ClusterLengths_GemmK  = 0;
     int ClusterLengths_GemmN  = 0;
-    int SrcDataPerRead_GemmN  = amd_buffer_load_max_length<float>();
-    int DstDataPerWrite_GemmN = amd_lds_write_max_length<float>();
+    int SrcDataPerRead_GemmN  = static_ck::amd_buffer_load_max_length<float>();
+    int DstDataPerWrite_GemmN = static_ck::amd_lds_write_max_length<float>();
 
     try
     {
@@ -343,7 +344,7 @@ std::tuple<int, bool>
 PerformanceImplicitGemmBwdDataV4R1::CalculateGemmCThreadCopyPerformanceParameters(
     const ProblemDescription& problem) const
 {
-    int DstDataPerWrite_GemmN1 = amd_buffer_store_max_length<float>();
+    int DstDataPerWrite_GemmN1 = static_ck::amd_buffer_store_max_length<float>();
 
     try
     {
@@ -523,7 +524,7 @@ bool PerformanceImplicitGemmBwdDataV4R1::IsValid(const ProblemDescription& probl
     std::size_t lds_size      = 0;
     std::tie(lds_size, valid) = CalculateLdsNumberOfByte(problem);
 
-    return (valid and lds_size <= get_lds_max_number_of_byte());
+    return (valid and lds_size <= static_ck::get_lds_max_number_of_byte());
 }
 
 void PerformanceImplicitGemmBwdDataV4R1::HeuristicInit(const ExecutionContext& ctx,
@@ -730,7 +731,7 @@ ConvHipImplicitGemmBwdDataV4R1::CalculateGemmSize(const ProblemDescription& prob
 bool ConvHipImplicitGemmBwdDataV4R1::IsApplicable(const ExecutionContext& ctx,
                                                   const ProblemDescription& problem) const
 {
-#if WORKAROUND_SWDEV_229277_227616_229195
+#if WORKAROUND_SWDEV_229277_227616_229195 || WORKAROUND_SWDEV_498660
     if(!env::enabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_BWD_V4R1))
         return false;
 #endif
@@ -742,9 +743,17 @@ bool ConvHipImplicitGemmBwdDataV4R1::IsApplicable(const ExecutionContext& ctx,
     if(problem.GetConv().attribute.deterministic)
         return false;
 
-    if(!IsComposableKernelSupportedHardware(ctx))
+    if(!static_ck::IsComposableKernelSupportedHardware(ctx))
         return false;
 
+    if(problem.IsFp32())
+    {
+        // Missing instruction: v_mac_f32
+        const auto dev_name = ctx.GetStream().GetDeviceName();
+        if(dev_name == "gfx942")
+            return false;
+    }
+
     if(!problem.IsDirectionBackwardData())
         return false;
 
@@ -772,7 +781,7 @@ bool ConvHipImplicitGemmBwdDataV4R1::IsApplicable(const ExecutionContext& ctx,
     if(!problem.IsLayoutDefault())
         return false;
 
-    if(!IsIndexRangeLargeEnough(problem))
+    if(!static_ck::IsIndexRangeLargeEnough(problem))
         return false;
 
     int gemm_m = 0;
@@ -797,7 +806,7 @@ PerformanceImplicitGemmBwdDataV4R1
 ConvHipImplicitGemmBwdDataV4R1::GetDefaultPerformanceConfig(const ExecutionContext& ctx,
                                                             const ProblemDescription& problem) const
 {
-    return GetPerformanceConfigBase<PerformanceImplicitGemmBwdDataV4R1>(ctx, problem);
+    return static_ck::GetPerformanceConfigBase<PerformanceImplicitGemmBwdDataV4R1>(ctx, problem);
 }
 
 bool ConvHipImplicitGemmBwdDataV4R1::IsValidPerformanceConfig(
@@ -948,10 +957,10 @@ ConvHipImplicitGemmBwdDataV4R1::GetSolution(const ExecutionContext& ctx,
                 std::string(" -DCK_PARAM_TUNABLE_GEMM_B_BLOCK_COPY_DST_DATA_PER_WRITE_GEMM_N=") + std::to_string(GemmBBlockCopyDstDataPerWrite_GemmN) +
                 std::string(" -DCK_PARAM_TUNABLE_GEMM_C_THREAD_COPY_DST_DATA_PER_WRITE_GEMM_N1=") + std::to_string(GemmCThreadCopyDstDataPerWrite_GemmN1) +
                 std::string(" -DCK_PARAM_DEPENDENT_GRID_SIZE=") + std::to_string(grid_size) +
-                std::string(" -DCK_THREADWISE_GEMM_USE_AMD_INLINE_ASM=") + (use_amd_inline_asm(ctx, problem) ? '1' : '0') +
-                std::string(" -DCK_USE_AMD_INLINE_ASM=") + (use_amd_inline_asm(ctx, problem) ? '1' : '0') +
+                std::string(" -DCK_THREADWISE_GEMM_USE_AMD_INLINE_ASM=") + (static_ck::use_amd_inline_asm(ctx, problem) ? '1' : '0') +
+                std::string(" -DCK_USE_AMD_INLINE_ASM=") + (static_ck::use_amd_inline_asm(ctx, problem) ? '1' : '0') +
                 std::string(" -DCK_PARAM_GEMM_ID=") + std::to_string(gemm_id) +
-                get_static_ck_common_compiler_flag(ctx) +
+                static_ck::get_static_ck_common_compiler_flag(ctx) +
                 ctx.general_compile_options;
             // clang-format on
 
