@@ -23,13 +23,13 @@
  * SOFTWARE.
  *
  *******************************************************************************/
+
 #include <miopen/conv/invokers/impl_gemm.hpp>
 #include <miopen/conv/solvers.hpp>
-#include <miopen/handle.hpp>
+#include <miopen/env.hpp>
 #include <miopen/generic_search.hpp>
-#include <miopen/solver/implicitgemm_util.hpp>
-
-#include <cstddef>
+#include <miopen/solver/implicitgemm_static_ck_util.hpp>
+#include <miopen/solver/static_ck_common.hpp>
 
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_FWD_V4R4)
 
@@ -181,8 +181,8 @@ PerformanceImplicitGemmV4R4Fwd::CalculateGemmABlockCopyPerformanceParameters() c
 {
     int ClusterLengths_GemmK  = 0;
     int ClusterLengths_GemmM  = 0;
-    int SrcDataPerRead_GemmK  = amd_buffer_load_max_length<float>();
-    int DstDataPerWrite_GemmM = amd_lds_write_max_length<float>();
+    int SrcDataPerRead_GemmK  = static_ck::amd_buffer_load_max_length<float>();
+    int DstDataPerWrite_GemmM = static_ck::amd_lds_write_max_length<float>();
 
     try
     {
@@ -231,8 +231,8 @@ PerformanceImplicitGemmV4R4Fwd::CalculateGemmBBlockCopyPerformanceParameters(
 {
     int ClusterLengths_GemmK  = 0;
     int ClusterLengths_GemmN  = 0;
-    int SrcDataPerRead_GemmN  = amd_buffer_load_max_length<float>();
-    int DstDataPerWrite_GemmN = amd_lds_write_max_length<float>();
+    int SrcDataPerRead_GemmN  = static_ck::amd_buffer_load_max_length<float>();
+    int DstDataPerWrite_GemmN = static_ck::amd_lds_write_max_length<float>();
 
     try
     {
@@ -337,7 +337,7 @@ PerformanceImplicitGemmV4R4Fwd::CalculateGemmBBlockCopyPerformanceParameters(
 std::tuple<int, bool> PerformanceImplicitGemmV4R4Fwd::CalculateGemmCThreadCopyPerformanceParameters(
     const ProblemDescription& problem) const
 {
-    int DstDataPerWrite_GemmN1 = amd_buffer_store_max_length<float>();
+    int DstDataPerWrite_GemmN1 = static_ck::amd_buffer_store_max_length<float>();
 
     try
     {
@@ -471,7 +471,7 @@ bool PerformanceImplicitGemmV4R4Fwd::IsValid(const ProblemDescription& problem)
     std::size_t lds_size      = 0;
     std::tie(lds_size, valid) = CalculateLdsNumberOfByte(problem);
 
-    return (valid and lds_size <= get_lds_max_number_of_byte());
+    return (valid and lds_size <= static_ck::get_lds_max_number_of_byte());
 }
 
 void PerformanceImplicitGemmV4R4Fwd::HeuristicInit(const ExecutionContext& ctx,
@@ -578,6 +578,10 @@ ConvHipImplicitGemmV4R4Fwd::CalculateGemmSize(const ProblemDescription& problem)
 bool ConvHipImplicitGemmV4R4Fwd::IsApplicable(const ExecutionContext& ctx,
                                               const ProblemDescription& problem) const
 {
+#if WORKAROUND_SWDEV_498660
+    if(!env::enabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_FWD_V4R4))
+        return false;
+#endif
     if(env::disabled(MIOPEN_DEBUG_CONV_IMPLICIT_GEMM_HIP_FWD_V4R4))
         return false;
     if(ThisSolverIsDeprecatedStatic::IsDisabled(ctx))
@@ -592,8 +596,14 @@ bool ConvHipImplicitGemmV4R4Fwd::IsApplicable(const ExecutionContext& ctx,
         return false;
     if(!problem.AllTensorsDimsFitIntoInt())
         return false;
-    if(!IsComposableKernelSupportedHardware(ctx))
+    if(!static_ck::IsComposableKernelSupportedHardware(ctx))
         return false;
+    {
+        // Missing instruction: v_mac_f32
+        const auto dev_name = ctx.GetStream().GetDeviceName();
+        if(dev_name == "gfx942")
+            return false;
+    }
     if(!problem.IsDirectionForward())
         return false;
     if(!problem.Is2d() && !problem.Is3d())
@@ -602,7 +612,7 @@ bool ConvHipImplicitGemmV4R4Fwd::IsApplicable(const ExecutionContext& ctx,
         return false;
     if(problem.GetGroupCount() != 1)
         return false;
-    if(!IsIndexRangeLargeEnough(problem))
+    if(!static_ck::IsIndexRangeLargeEnough(problem))
         return false;
 
     if(problem.IsTensorsCasted())
@@ -620,7 +630,7 @@ PerformanceImplicitGemmV4R4Fwd
 ConvHipImplicitGemmV4R4Fwd::GetDefaultPerformanceConfig(const ExecutionContext& ctx,
                                                         const ProblemDescription& problem) const
 {
-    return GetPerformanceConfigBase<PerformanceImplicitGemmV4R4Fwd>(ctx, problem);
+    return static_ck::GetPerformanceConfigBase<PerformanceImplicitGemmV4R4Fwd>(ctx, problem);
 }
 
 bool ConvHipImplicitGemmV4R4Fwd::IsValidPerformanceConfig(
@@ -757,9 +767,9 @@ ConvHipImplicitGemmV4R4Fwd::GetSolution(const ExecutionContext& ctx,
         std::string(" -DCK_PARAM_TUNABLE_GEMM_B_BLOCK_COPY_DST_DATA_PER_WRITE_GEMM_N=") + std::to_string(GemmBBlockCopyDstDataPerWrite_GemmN) +
         std::string(" -DCK_PARAM_TUNABLE_GEMM_C_THREAD_COPY_DST_DATA_PER_WRITE_GEMM_N1=") + std::to_string(GemmCThreadCopyDstDataPerWrite_GemmN1) +
         std::string(" -DCK_PARAM_DEPENDENT_GRID_SIZE=") + std::to_string(grid_size) +
-        std::string(" -DCK_THREADWISE_GEMM_USE_AMD_INLINE_ASM=") + (use_amd_inline_asm(ctx, problem) ? '1' : '0') +
-        std::string(" -DCK_USE_AMD_INLINE_ASM=") + (use_amd_inline_asm(ctx, problem) ? '1' : '0') +
-        get_static_ck_common_compiler_flag(ctx) +
+        std::string(" -DCK_THREADWISE_GEMM_USE_AMD_INLINE_ASM=") + (static_ck::use_amd_inline_asm(ctx, problem) ? '1' : '0') +
+        std::string(" -DCK_USE_AMD_INLINE_ASM=") + (static_ck::use_amd_inline_asm(ctx, problem) ? '1' : '0') +
+        static_ck::get_static_ck_common_compiler_flag(ctx) +
         ctx.general_compile_options;
 
         if (problem.Is3d()){
