@@ -49,6 +49,7 @@
 #include <mutex>
 #include <shared_mutex>
 #include <string>
+#include <thread>
 
 extern "C" {
 int miopen_sqlite3_memvfs_init(sqlite3* db, char** pzErrMsg, const sqlite3_api_routines* pApi);
@@ -62,7 +63,7 @@ class SQLite::impl
         void operator()(sqlite3* ptr)
         {
             const auto c_filename = sqlite3_db_filename(ptr, "main");
-            std::string filename_((c_filename == nullptr) ? "" : c_filename);
+            fs::path filename_((c_filename == nullptr) ? "" : c_filename);
             SQLite::Retry([&]() { return sqlite3_close(ptr); }, filename_);
             // Future: Sync the file back to disk, unless disk I/O is disabled
             // Get the page_count: pragma page_count;
@@ -95,10 +96,10 @@ class SQLite::impl
         if(is_system)
         {
 
-            const auto& it_p = miopen_data().find(filepath.filename().string() + ".o");
+            const auto& it_p = miopen_data().find(make_object_file_name(filepath.filename()));
             if(it_p == miopen_data().end())
             {
-                MIOPEN_LOG_I("Unknown database: " + filepath.string() + " in internal file cache");
+                MIOPEN_LOG_I("Unknown database: " << filepath << " in internal file cache");
                 return SQLITE_ERROR;
             }
             const auto& p    = it_p->second;
@@ -150,8 +151,8 @@ class SQLite::impl
         int rc           = 0;
         if(is_system)
         {
-            if(fs::file_size(filepath) <
-               512) // size of a very small database, Empty MIOpen DBs are 20 kb
+            // size of a very small database, Empty MIOpen DBs are 20 kb
+            if(fs::file_size(filepath) < 512)
             {
                 rc = -1;
                 return rc;
@@ -174,14 +175,13 @@ class SQLite::impl
     }
 
 public:
-    impl(const std::string& filename_, bool is_system)
+    impl(const fs::path& filename_, bool is_system)
     {
-        fs::path filepath(filename_);
         int rc = 0;
 #if MIOPEN_EMBED_DB
-        rc = CreateInMemDb(filepath, is_system);
+        rc = CreateInMemDb(filename_, is_system);
 #else
-        rc = CreateFileDb(filepath, is_system);
+        rc = CreateFileDb(filename_, is_system);
 #endif
         isValid = (rc == 0);
         if(isValid)
@@ -230,7 +230,7 @@ SQLite::result_type SQLite::Exec(const std::string& query) const
     return res;
 }
 
-int SQLite::Retry(std::function<int()> f, [[maybe_unused]] std::string filename)
+int SQLite::Retry(std::function<int()> f, [[maybe_unused]] fs::path filename)
 {
 #if !MIOPEN_ENABLE_SQLITE_BACKOFF
     int rc = f();
@@ -270,7 +270,7 @@ int SQLite::Retry(std::function<int()> f, [[maybe_unused]] std::string filename)
 
 int SQLite::Retry(std::function<int()> f) const
 {
-    std::string filename(sqlite3_db_filename(pImpl->ptrDb.get(), "main"));
+    fs::path filename(sqlite3_db_filename(pImpl->ptrDb.get(), "main"));
     return SQLite::Retry(f, filename);
 }
 
@@ -319,7 +319,7 @@ public:
     sqlite3_stmt_ptr ptrStmt = nullptr;
 };
 
-SQLite::SQLite(const std::string& filename_, bool is_system)
+SQLite::SQLite(const fs::path& filename_, bool is_system)
     : pImpl{std::make_unique<impl>(filename_, is_system)}
 {
 }
@@ -349,12 +349,13 @@ std::string SQLite::Statement::ColumnText(int idx)
         reinterpret_cast<const char*>(sqlite3_column_text(pImpl->ptrStmt.get(), idx)), bytes};
 }
 
-std::string SQLite::Statement::ColumnBlob(int idx)
+std::vector<char> SQLite::Statement::ColumnBlob(int idx)
 {
-    auto ptr = sqlite3_column_blob(pImpl->ptrStmt.get(), idx);
+    auto ptr = static_cast<const char*>(sqlite3_column_blob(pImpl->ptrStmt.get(), idx));
     auto sz  = sqlite3_column_bytes(pImpl->ptrStmt.get(), idx);
-    return std::string{reinterpret_cast<const char*>(ptr), static_cast<size_t>(sz)};
+    return {ptr, ptr + sz};
 }
+
 int64_t SQLite::Statement::ColumnInt64(int idx)
 {
     return sqlite3_column_int64(pImpl->ptrStmt.get(), idx);
@@ -366,7 +367,13 @@ int SQLite::Statement::BindText(int idx, const std::string& txt)
         pImpl->ptrStmt.get(), idx, txt.data(), txt.size(), SQLITE_TRANSIENT); // NOLINT
     return 0;
 }
-int SQLite::Statement::BindBlob(int idx, const std::string& blob)
+
+int SQLite::Statement::BindPath(int idx, const fs::path& path)
+{
+    return BindText(idx, path.string());
+}
+
+int SQLite::Statement::BindBlob(int idx, const std::vector<char>& blob)
 {
     sqlite3_bind_blob(
         pImpl->ptrStmt.get(), idx, blob.data(), blob.size(), SQLITE_TRANSIENT); // NOLINT
@@ -379,8 +386,8 @@ int SQLite::Statement::BindInt64(int idx, const int64_t num)
     return 0;
 }
 
-SQLitePerfDb::SQLitePerfDb(const std::string& filename_, bool is_system_)
-    : SQLiteBase(filename_, is_system_)
+SQLitePerfDb::SQLitePerfDb(DbKinds db_kind, const fs::path& filename_, bool is_system_)
+    : SQLiteBase(db_kind, filename_, is_system_)
 {
     if(DisableUserDbFileIO && !is_system)
         return;
@@ -390,7 +397,7 @@ SQLitePerfDb::SQLitePerfDb(const std::string& filename_, bool is_system_)
         if(filename.empty())
             MIOPEN_LOG_I("database not present");
         else
-            MIOPEN_LOG_I(filename + " database invalid");
+            MIOPEN_LOG_I(filename << " database invalid");
         return;
     }
 
@@ -457,7 +464,7 @@ SQLitePerfDb::SQLitePerfDb(const std::string& filename_, bool is_system_)
         }
         if(!CheckTableColumns("perf_db", {"solver", "config", "params"}))
         {
-            MIOPEN_LOG_W("Invalid fields in table: perf_db disabling access to " + filename);
+            MIOPEN_LOG_W("Invalid fields in table: perf_db disabling access to " << filename);
             dbInvalid = true;
         }
     }
