@@ -41,6 +41,7 @@
 #include <miopen/batch_norm.hpp>
 #include <miopen/miopen.h>
 #include <miopen/tensor.hpp>
+#include <miopen/activ.hpp>
 #include <utility>
 #include <cfloat>
 // Run CPU emulations in hierarchical reduction mode.
@@ -318,6 +319,7 @@ struct verify_forward_train_3d_bn_spatial
         float alpha = 1.0;
         float beta  = 0.0;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardTraining(handle,
                                          miopenBNSpatial,
                                          &alpha,
@@ -337,7 +339,8 @@ struct verify_forward_train_3d_bn_spatial
                                          runVar_dev.get(),
                                          epsilon,
                                          saveMean_dev.get(),
-                                         saveInvVar_dev.get());
+                                         saveInvVar_dev.get(),
+                                         actDesc);
 
         saveMean.data   = handle.Read<U>(saveMean_dev, saveMean.data.size());
         saveInvVar.data = handle.Read<U>(saveInvVar_dev, saveInvVar.data.size());
@@ -510,6 +513,7 @@ struct verify_forward_infer_3d_bn_spatial_recalc
 
         double epsilon = MIO_BN_TEST_EPSILON;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardInference(handle,
                                           miopenBNSpatial,
                                           &alpha,
@@ -526,7 +530,8 @@ struct verify_forward_infer_3d_bn_spatial_recalc
                                           shift_dev.get(),
                                           nullptr,
                                           nullptr,
-                                          epsilon);
+                                          epsilon,
+                                          actDesc);
         out.data = handle.Read<T>(out_dev, out.data.size());
 
 #if(MIO_BN_TIME_EVERYTHING == 1)
@@ -629,6 +634,7 @@ struct verify_forward_infer_3d_bn_spatial_use_est
 
         double epsilon = MIO_BN_TEST_EPSILON;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardInference(handle,
                                           miopenBNSpatial,
                                           &alpha,
@@ -645,7 +651,8 @@ struct verify_forward_infer_3d_bn_spatial_use_est
                                           shift_dev.get(),
                                           estMean_dev.get(),
                                           estVar_dev.get(),
-                                          epsilon);
+                                          epsilon,
+                                          actDesc);
         out.data = handle.Read<T>(out_dev, out.data.size());
 #if(MIO_BN_TIME_EVERYTHING == 1)
         auto t_end = std::chrono::high_resolution_clock::now();
@@ -909,6 +916,7 @@ struct verify_backward_3d_bn_spatial_recalc
 
         double epsilon = MIO_BN_TEST_EPSILON;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormBackward(handle,
                                   miopenBNSpatial,
                                   &alpha,
@@ -926,11 +934,13 @@ struct verify_backward_3d_bn_spatial_recalc
                                   miopen::BuildReshaped4DTensorDescriptor(dshift.desc),
                                   miopen::BuildReshaped4DTensorDescriptor(dshift.desc),
                                   scale_dev.get(),
+                                  nullptr,
                                   dscale_dev.get(),
                                   dshift_dev.get(),
                                   epsilon,
                                   nullptr,
-                                  nullptr);
+                                  nullptr,
+                                  actDesc);
 
         dx_out.data = handle.Read<T>(dx_out_dev, dx_out.data.size());
         dscale.data = handle.Read<U>(dscale_dev, dscale.data.size());
@@ -1137,6 +1147,7 @@ struct verify_backward_3d_bn_spatial_use_saved
 
         double epsilon = MIO_BN_TEST_EPSILON;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormBackward(handle,
                                   miopenBNSpatial,
                                   &alpha,
@@ -1154,11 +1165,13 @@ struct verify_backward_3d_bn_spatial_use_saved
                                   miopen::BuildReshaped4DTensorDescriptor(dshift.desc),
                                   miopen::BuildReshaped4DTensorDescriptor(dshift.desc),
                                   scale_dev.get(),
+                                  nullptr,
                                   dscale_dev.get(),
                                   dshift_dev.get(),
                                   epsilon,
                                   savedMean_dev.get(),
-                                  savedInvVar_dev.get());
+                                  savedInvVar_dev.get(),
+                                  actDesc);
 
         dx_out.data = handle.Read<T>(dx_out_dev, dx_out.data.size());
         dscale.data = handle.Read<U>(dscale_dev, dscale.data.size());
@@ -1203,6 +1216,8 @@ struct batch_norm_3d_spatial_driver : test_driver
     batch_norm_3d_spatial_driver()
     {
         this->batch_factor = 4;
+        this->tolerance =
+            4e-3 / std::numeric_limits<T>::epsilon(); // ck solver has tolerance of 4e-3
         add(input,
             "input",
             get_3d_bn_spatial_input_tensor(
@@ -1233,34 +1248,18 @@ struct batch_norm_3d_spatial_driver : test_driver
         miopen::DeriveBNTensorDescriptor(derivedBnDesc, input.desc, miopenBNSpatial);
         std::tie(ssn, ssc, ssd, ssh, ssw) = miopen::tien<5>(derivedBnDesc.GetLengths());
 
-        if(input.desc.GetType() == miopenFloat)
-        {
-            scale =
-                tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw}.generate(tensor_elem_gen_integer{17});
-            shift =
-                tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw}.generate(tensor_elem_gen_integer{17});
+        scale                   = tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw};
+        shift                   = tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw};
+        const double Data_scale = 1e-4;
 
-            if(d * h * w < 3072)
-            {
-                std::cout << "Choosing smaller input values for low dims" << std::endl;
-                input = tensor<T>{n, c, d, h, w}.generate(tensor_elem_gen_integer{7});
-            }
+        for(std::size_t i = 0; i < scale.desc.GetElementSize(); i++)
+        {
+            scale[i] = prng::gen_descreet_uniform_sign<PREC_TYPE>(Data_scale, 100);
+            shift[i] = prng::gen_descreet_uniform_sign<PREC_TYPE>(Data_scale, 100);
         }
-        else
+        for(std::size_t i = 0; i < input.desc.GetElementSize(); i++)
         {
-            scale = tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw};
-            shift = tensor<PREC_TYPE>{ssn, ssc, ssd, ssh, ssw};
-
-            const double Data_scale = 1e-4;
-            for(std::size_t i = 0; i < scale.desc.GetElementSize(); i++)
-            {
-                scale[i] = prng::gen_descreet_uniform_sign<PREC_TYPE>(Data_scale, 100);
-                shift[i] = prng::gen_descreet_uniform_sign<PREC_TYPE>(Data_scale, 100);
-            }
-            for(std::size_t i = 0; i < input.desc.GetElementSize(); i++)
-            {
-                input[i] = prng::gen_descreet_uniform_sign<T>(1e-5, 100);
-            }
+            input[i] = prng::gen_descreet_uniform_sign<T>(1e-5, 100);
         }
 
 // train
