@@ -34,6 +34,7 @@
 #include <miopen/batch_norm.hpp>
 #include <miopen/miopen.h>
 #include <miopen/tensor.hpp>
+#include <miopen/activ.hpp>
 #include <utility>
 
 #include "driver.hpp"
@@ -262,6 +263,7 @@ struct verify_forward_train_bn_per_activation
         float alpha = 1.;
         float beta  = 0.;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardTraining(handle,
                                          miopenBNPerActivation,
                                          &alpha,
@@ -271,6 +273,9 @@ struct verify_forward_train_bn_per_activation
                                          out.desc,
                                          out_dev.get(),
                                          scale.desc,
+                                         shift.desc,
+                                         shift.desc,
+                                         shift.desc,
                                          scale_dev.get(),
                                          shift_dev.get(),
                                          expAvgFactor,
@@ -278,7 +283,8 @@ struct verify_forward_train_bn_per_activation
                                          runVar_dev.get(),
                                          epsilon,
                                          saveMean_dev.get(),
-                                         saveInvVar_dev.get());
+                                         saveInvVar_dev.get(),
+                                         actDesc);
 
         saveMean.data   = handle.Read<U>(saveMean_dev, saveMean.data.size());
         saveInvVar.data = handle.Read<U>(saveInvVar_dev, saveInvVar.data.size());
@@ -424,6 +430,7 @@ struct verify_forward_infer_bn_per_activation_recalc
         float alpha = 1.;
         float beta  = 0.;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardInference(handle,
                                           miopenBNPerActivation,
                                           &alpha,
@@ -433,11 +440,15 @@ struct verify_forward_infer_bn_per_activation_recalc
                                           out.desc,
                                           out_dev.get(),
                                           scale.desc,
+                                          shift.desc,
+                                          shift.desc,
+                                          shift.desc,
                                           scale_dev.get(),
                                           shift_dev.get(),
                                           nullptr,
                                           nullptr,
-                                          epsilon);
+                                          epsilon,
+                                          actDesc);
         out.data = handle.Read<T>(out_dev, out.data.size());
 
 #if(MIO_BN_TIME_EVERYTHING == 1)
@@ -541,6 +552,7 @@ struct verify_forward_infer_bn_per_activation_use_est
         float alpha = 1.;
         float beta  = 0.;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormForwardInference(handle,
                                           miopenBNPerActivation,
                                           &alpha,
@@ -550,11 +562,15 @@ struct verify_forward_infer_bn_per_activation_use_est
                                           out.desc,
                                           out_dev.get(),
                                           scale.desc,
+                                          shift.desc,
+                                          shift.desc,
+                                          shift.desc,
                                           scale_dev.get(),
                                           shift_dev.get(),
                                           estMean_dev.get(),
                                           estVar_dev.get(),
-                                          epsilon); // TODO: add multi-in
+                                          epsilon,
+                                          actDesc); // TODO: add multi-in
         out.data = handle.Read<T>(out_dev, out.data.size());
 
 #if(MIO_BN_TIME_EVERYTHING == 1)
@@ -703,6 +719,7 @@ struct verify_backward_bn_per_activation_use_saved
         float alpha = 1.;
         float beta  = 0.;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormBackward(handle,
                                   miopenBNPerActivation,
                                   &alpha,
@@ -716,12 +733,17 @@ struct verify_backward_bn_per_activation_use_saved
                                   dx_out.desc,
                                   dx_out_dev.get(),
                                   scale.desc,
+                                  dshift.desc,
+                                  dshift.desc,
+                                  dshift.desc,
                                   scale_dev.get(),
+                                  nullptr,
                                   dscale_dev.get(),
                                   dshift_dev.get(),
                                   epsilon,
                                   savedMean_dev.get(),
-                                  savedInvVar_dev.get());
+                                  savedInvVar_dev.get(),
+                                  actDesc);
         dx_out.data = handle.Read<T>(dx_out_dev, dx_out.data.size());
         dscale.data = handle.Read<U>(dscale_dev, dscale.data.size());
         dshift.data = handle.Read<U>(dshift_dev, dshift.data.size());
@@ -896,6 +918,7 @@ struct verify_backward_bn_per_activation_recalc
         float alpha = 1.;
         float beta  = 0.;
 
+        miopen::ActivationDescriptor actDesc(miopenActivationPASTHRU, 0.0f, 0.0f, 0.0f);
         miopen::BatchNormBackward(handle,
                                   miopenBNPerActivation,
                                   &alpha,
@@ -909,12 +932,17 @@ struct verify_backward_bn_per_activation_recalc
                                   dx_out.desc,
                                   dx_out_dev.get(),
                                   scale.desc,
+                                  dshift.desc,
+                                  dshift.desc,
+                                  dshift.desc,
                                   scale_dev.get(),
+                                  nullptr,
                                   dscale_dev.get(),
                                   dshift_dev.get(),
                                   epsilon,
                                   nullptr,
-                                  nullptr);
+                                  nullptr,
+                                  actDesc);
         dx_out.data = handle.Read<T>(dx_out_dev, dx_out.data.size());
         dscale.data = handle.Read<U>(dscale_dev, dscale.data.size());
         dshift.data = handle.Read<U>(dshift_dev, dshift.data.size());
