@@ -26,7 +26,7 @@
 #include <gtest/gtest.h>
 #include <miopen/fusion/solvers.hpp>
 #include <miopen/fusion/fusion_invoke_params.hpp>
-#include <miopen/env.hpp>
+#include <gtest/gtest_common.hpp>
 
 #include "tensor_holder.hpp"
 #include "get_handle.hpp"
@@ -139,7 +139,7 @@ private:
     miopen::TensorDescriptor bias_des;
     miopen::TensorDescriptor weights_des;
 
-    miopen::Handle& handle;
+    const miopen::Handle& handle;
 
     miopen::ConvolutionDescriptor conv_desc;
     miopen::ActivationDescriptor activ_desc;
@@ -237,7 +237,8 @@ TEST(GPU_FusionPlan_FP16, BadEmptyFusionPlan)
 
 TEST(GPU_FusionPlan_FP16, UnSupportedFusionPlanDuringSearchMode)
 {
-    env::setEnvironmentVariable("MIOPEN_FIND_ENFORCE", "3");
+
+    ScopedEnvironment<std::string> find_enforce_env2(MIOPEN_FIND_ENFORCE, "SEARCH_DB_UPDATE");
     GPU_FusionPlan_FP16<miopen::solver::fusion::ConvCKIgemmFwdBiasActivFused, half_float::half> obj(
         miopenTensorNHWC, miopenActivationRELU);
     if(obj.Skip())
