@@ -28,11 +28,9 @@
 #include <miopen/miopen.h>
 #include <gtest/gtest.h>
 #include <miopen/miopen.h>
-#include <miopen/env.hpp>
 #include "get_handle.hpp"
-#include "test_env.hpp"
-
 #include "../conv2d.hpp"
+#include "gtest_common.hpp"
 
 namespace conv_embed_db {
 
@@ -47,15 +45,19 @@ void GetArgs(const std::string& param, std::vector<std::string>& tokens)
 
 class CPU_ConvEmbedConfig_FP16 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 class CPU_ConvEmbedConfig_I8 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 class CPU_ConvEmbedConfig_BFP16 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 class CPU_ConvEmbedConfig_FP32 : public testing::TestWithParam<std::vector<std::string>>
 {
+    MIOPEN_DECLARE_GTEST_USES_TEST_DRIVE();
 };
 
 void Run2dDriver(miopenDataType_t prec)
@@ -70,10 +72,10 @@ void Run2dDriver(miopenDataType_t prec)
     case miopenBFloat16: params = CPU_ConvEmbedConfig_BFP16::GetParam(); break;
     case miopenInt64:
     case miopenInt32:
-    case miopenFloat8:
-    case miopenBFloat8:
+    case miopenFloat8_fnuz:
+    case miopenBFloat8_fnuz:
     case miopenDouble:
-        FAIL() << "miopenInt32, miopenFloat8, miopenBFloat8, miopenDouble data type "
+        FAIL() << "miopenInt32, miopenFloat8_fnuz, miopenBFloat8_fnuz, miopenDouble data type "
                   "not supported by conv_embed_db test";
 
     default: params = CPU_ConvEmbedConfig_FP32::GetParam();
@@ -145,7 +147,7 @@ TEST_P(CPU_ConvEmbedConfig_FP32, FloatTest_conv_embed_db)
 #if MIOPEN_EMBED_DB
 
     const auto& handle = get_handle();
-    if(IsTestSupportedForDevice(handle) && IsTestRunWith("--float"))
+    if(IsTestSupportedForDevice(handle))
     {
         Run2dDriver(miopenFloat);
     }
@@ -164,7 +166,7 @@ TEST_P(CPU_ConvEmbedConfig_FP16, HalfTest_conv_embed_db)
 #if MIOPEN_EMBED_DB
 
     const auto& handle = get_handle();
-    if(IsTestSupportedForDevice(handle) && IsTestRunWith("--half"))
+    if(IsTestSupportedForDevice(handle))
     {
         Run2dDriver(miopenHalf);
     }
@@ -183,7 +185,7 @@ TEST_P(CPU_ConvEmbedConfig_I8, Int8Test_conv_embed_db)
 #if MIOPEN_EMBED_DB
 
     const auto& handle = get_handle();
-    if(IsTestSupportedForDevice(handle) && IsTestRunWith("--int8"))
+    if(IsTestSupportedForDevice(handle))
     {
         Run2dDriver(miopenInt8);
     }
@@ -202,7 +204,7 @@ TEST_P(CPU_ConvEmbedConfig_BFP16, BFloat16Test_conv_embed_db)
 #if MIOPEN_EMBED_DB
 
     const auto& handle = get_handle();
-    if(IsTestSupportedForDevice(handle) && IsTestRunWith("--bfloat16"))
+    if(IsTestSupportedForDevice(handle))
     {
         Run2dDriver(miopenBFloat16);
     }
