@@ -28,7 +28,10 @@
 
 #include <miopen/miopen.h>
 #include "get_handle.hpp"
+#include "../lib_env_var.hpp"
+#include "gtest_common.hpp"
 #include <miopen/readonlyramdb.hpp>
+#include <miopen/env.hpp>
 #include <miopen/execution_context.hpp>
 
 #include <miopen/find_db.hpp>
@@ -43,6 +46,7 @@
 #include <cstdlib>
 #include <regex>
 #include <exception>
+#include <thread>
 #include <unordered_set>
 
 /// \todo HACK
@@ -51,9 +55,8 @@
 /// src/solver/conv_winoRxS.cpp
 #define WORKAROUND_ISSUE_2492 1
 
-#if WORKAROUND_ISSUE_2492 && defined(_WIN32)
-#define WIN32_LEAN_AND_MEAN
-#include <Windows.h>
+#if WORKAROUND_ISSUE_2492
+MIOPEN_LIB_ENV_VAR(MIOPEN_DEBUG_WORKAROUND_ISSUE_2492)
 #endif
 
 #define WORKAROUND_ISSUE_1987 0      // Allows testing FDB on gfx1030 (legacy fdb).
@@ -85,14 +88,6 @@ struct std::hash<KDBKey>
     }
 };
 
-#if WORKAROUND_ISSUE_2492 && !defined(_WIN32)
-static void SetEnvironmentVariable(std::string_view name, std::string_view value)
-{
-    const auto ret = setenv(name.data(), value.data(), 1);
-    ASSERT_TRUE(ret == 0);
-}
-#endif // WORKAROUND_ISSUE_2492
-
 #if WORKAROUND_ISSUE_1987
 /// \todo Copied from src/db_record.cpp
 /// Transform find-db (v.1.0) ID:VALUES to the current format.
@@ -527,9 +522,18 @@ void SetupPaths(fs::path& fdb_file_path,
 
 TEST(CPU_DBSync_NONE, KDBTargetID)
 {
+    // Skip this test for gfx11 and gfx12 to avoid test failure (we don't have databases for those
+    // devices yet)
+    const auto& handle = get_handle();
+    if(miopen::StartsWith(handle.GetDeviceName(), "gfx11") ||
+       miopen::StartsWith(handle.GetDeviceName(), "gfx12"))
+    {
+        GTEST_SKIP();
+    }
+
     fs::path fdb_file_path, pdb_file_path, kdb_file_path;
 #if WORKAROUND_ISSUE_2492
-    SetEnvironmentVariable("MIOPEN_DEBUG_WORKAROUND_ISSUE_2492", "0");
+    ScopedEnvironment<std::string> issue_2492_env(MIOPEN_DEBUG_WORKAROUND_ISSUE_2492, "0");
 #endif
     SetupPaths(fdb_file_path, pdb_file_path, kdb_file_path, get_handle());
     std::ignore = fdb_file_path;
@@ -741,7 +745,10 @@ void CheckFDBEntry(size_t thread_index,
             }
 #endif
 
+            miopen::solver::ConvSolution sol;
+            auto db         = miopen::GetDb(ctx);
             const auto solv = id.GetSolver();
+
             // Skip MLIR
             if(miopen::StartsWith(id.ToString(), "ConvMlir"))
             {
@@ -749,15 +756,27 @@ void CheckFDBEntry(size_t thread_index,
                 ++fdb_idx;
                 continue;
             }
-            EXPECT_TRUE(solv.IsApplicable(ctx, problem)) //
-                << '[' << (++failures) << "] "           //
-                << "Solver is not applicable fdb-key:" << kinder.first
-                << " Solver: " << id.ToString();
-            miopen::solver::ConvSolution sol;
 
-            auto db                     = miopen::GetDb(ctx);
+            if(env::enabled(MIOPEN_DBSYNC_CLEAN) && not solv.IsApplicable(ctx, problem))
+            {
+                MIOPEN_LOG_W("Inapplicable solver found fdb-key:"
+                             << kinder.first << ", Solver" << val.solver_id << ":"
+                             << ", Removing entry from fdb and pdb");
+                find_db_rw.Remove(kinder.first, id.ToString());
+                db.Remove(problem, id.ToString());
+                MIOPEN_LOG_W("Removal Complete fdb-key:" << kinder.first << ": solver"
+                                                         << val.solver_id);
+                continue;
+            }
+            else
+            {
+                EXPECT_TRUE(solv.IsApplicable(ctx, problem)) //
+                    << '[' << (++failures) << "] "           //
+                    << "Solver is not applicable fdb-key:" << kinder.first
+                    << " Solver: " << id.ToString();
+            }
+
             const auto pdb_entry_exists = pdb_vals.find(val.solver_id) != pdb_vals.end();
-
             if(solv.IsTunable())
             {
                 if(env::enabled(MIOPEN_DBSYNC_CLEAN) && not pdb_entry_exists)
