@@ -35,6 +35,9 @@
     ((HIP_PACKAGE_VERSION_FLAT >= 6000000000ULL && HIP_PACKAGE_VERSION_FLAT <= 6000999999ULL) || \
      (HIP_PACKAGE_VERSION_FLAT >= 6001000000ULL && HIP_PACKAGE_VERSION_FLAT <= 6001024049ULL))
 
+// Temporarily disable warnings as errors for kernel builds to see real breaks with compiler changes
+#define MIOPEN_WORKAROUND_COMPILER_CHANGE 1
+
 #include <miopen/config.h>
 #include <miopen/handle.hpp>
 #include <miopen/execution_context.hpp>
@@ -95,7 +98,7 @@ std::string Write2s(kernel_type_t kern_type)
     }
 }
 
-void run2s(miopen::Handle& h, std::size_t n, kernel_type_t kern_type)
+void run2s(const miopen::Handle& h, std::size_t n, kernel_type_t kern_type)
 {
     std::vector<int> data_in(n, 1);
     auto data_dev = h.Write(data_in);
@@ -258,7 +261,7 @@ std::string WriteNop(kernel_type_t kern_type)
 void test_warnings(kernel_type_t kern_type)
 {
     auto&& h = get_handle();
-#if MIOPEN_BUILD_DEV && !WORKAROUND_ISSUE_2600
+#if MIOPEN_BUILD_DEV && !WORKAROUND_ISSUE_2600 && !MIOPEN_WORKAROUND_COMPILER_CHANGE
     if(kern_type == miopenOpenCLKernelType)
     {
         EXPECT(throws([&] {
@@ -302,9 +305,8 @@ void test_arch_name()
                        "gfx90a",
                        "gfx906",
                        "gfx900",
-                       "gfx940",
-                       "gfx941",
                        "gfx942",
+                       "gfx950",
                        "gfx803",
                        "gfx1030",
                        "gfx1031",
